# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
	def test_decfloat(self):
		obj = IbmDbTestFunctions()
		obj.assert_expect(self.run_test_decfloat)
	
	def run_test_decfloat(self):
		conn = ibm_db.connect(config.database, config.user, config.password)
		
		if conn:
			serverinfo = ibm_db.server_info( conn )
			
			drop = "DROP TABLE STOCKPRICE"
			try:
				result = ibm_db.exec_immediate(conn,drop)
			except:
				pass
			
			# Create the table stockprice
			create = "CREATE TABLE STOCKPRICE (id SMALLINT NOT NULL, company VARCHAR(30), stockshare DECIMAL(7,2), stockprice DECFLOAT(16))"
			result = ibm_db.exec_immediate(conn, create)
			
			# Insert Directly
			insert = "INSERT INTO STOCKPRICE (id, company, stockshare, stockprice) VALUES (10,'Megadeth', 100.002,990.356736488388374888532323)"
			result = ibm_db.exec_immediate(conn, insert)
			
			# Prepare and Insert in the stockprice table
			stockprice = (\
					(20, "Zaral", 102.205, "100.234"),\
					(30, "Megabyte", 98.65, "1002.112"),\
					(40, "Visarsoft", 123.34, "1652.345"),\
					(50, "Mailersoft", 134.22, "1643.126"),\
					(60, "Kaerci", 100.97, "9876.765")\
					)
			insert = 'INSERT INTO STOCKPRICE (id, company, stockshare,stockprice) VALUES (?,?,?,?)'
			stmt = ibm_db.prepare(conn,insert)
			if stmt:
				for company in stockprice:
					result = ibm_db.execute(stmt,company)
			
			id = 70
			company = 'Nirvana'
			stockshare = 100.1234
			stockprice = "100.567"
			try:
				ibm_db.bind_param(stmt, 1, id)
				ibm_db.bind_param(stmt, 2, company)
				ibm_db.bind_param(stmt, 3, stockshare)
				ibm_db.bind_param(stmt, 4, stockprice)
				error = ibm_db.execute(stmt);
			except:
				excp = sys.exc_info()
				# slot 1 contains error message
				print excp[1]
			
			# Select the result from the table and
			query = 'SELECT * FROM STOCKPRICE ORDER BY id'
			if (serverinfo.DBMS_NAME[0:3] != 'IDS'):
				stmt = ibm_db.prepare(conn, query, {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_KEYSET_DRIVEN})
			else:
				stmt = ibm_db.prepare(conn, query)
			ibm_db.execute(stmt)
			data = ibm_db.fetch_both( stmt )
			while ( data ):
				print "%s : %s : %s : %s\n" % (data[0], data[1], data[2], data[3])
				data = ibm_db.fetch_both( stmt )
			try:
				stmt = ibm_db.prepare(conn, query, {ibm_db.SQL_ATTR_CURSOR_TYPE:  ibm_db.SQL_CURSOR_KEYSET_DRIVEN})
				ibm_db.execute(stmt)
				rc = ibm_db.fetch_row(stmt, -1)
				print "Fetch Row -1:%s " %str(rc)
			except:
				print "Requested row number must be a positive value"
			ibm_db.close(conn)
		else:
			print "Connection failed."

#__END__
#__LUW_EXPECTED__
#10 : Megadeth : 100.00 : 990.3567364883884
#20 : Zaral : 102.20 : 100.234
#30 : Megabyte : 98.65 : 1002.112
#40 : Visarsoft : 123.34 : 1652.345
#50 : Mailersoft : 134.22 : 1643.126
#60 : Kaerci : 100.97 : 9876.765
#70 : Nirvana : 100.12 : 100.567
#Requested row number must be a positive value
#__ZOS_EXPECTED__
#10 : Megadeth : 100.00 : 990.3567364883884
#20 : Zaral : 102.20 : 100.234
#30 : Megabyte : 98.65 : 1002.112
#40 : Visarsoft : 123.34 : 1652.345
#50 : Mailersoft : 134.22 : 1643.126
#60 : Kaerci : 100.97 : 9876.765
#70 : Nirvana : 100.12 : 100.567
#Requested row number must be a positive value



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_250_FreeResult_01(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_250)

  def run_test_250(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    result = ibm_db.exec_immediate(conn, "select * from sales")
    result2 = ibm_db.exec_immediate(conn, "select * from staff")
    result3 = ibm_db.exec_immediate(conn, "select * from emp_photo")
    
    r1 = ibm_db.free_result(result)
    r2 = ibm_db.free_result(result2)
    r3 = ibm_db.free_result(result3)
    
    print r1
    print r2
    print r3

#__END__
#__LUW_EXPECTED__
#True
#True
#True
#__ZOS_EXPECTED__
#True
#True
#True
#__SYSTEMI_EXPECTED__
#True
#True
#True
#__IDS_EXPECTED__
#True
#True
#True



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_133_ExecuteLongInputParams(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_133)

  def run_test_133(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    if (not conn):
      print "Connection failed."
      return 0

    ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

    print "Starting test ..."
    res = ''
    sql =  "INSERT INTO animals (id, breed, name, weight) VALUES (?, ?, ?, ?)"
    try:
      stmt = ibm_db.prepare(conn, sql)
      res = ibm_db.execute(stmt,(128, 'hacker of human and technological nature', 'Wez the ruler of all things PECL', 88.3))
      
      stmt = ibm_db.prepare(conn, "SELECT breed, name FROM animals WHERE id = ?")
      res = ibm_db.execute(stmt, (128,))
      row = ibm_db.fetch_assoc(stmt)
      
      for i in row:
	         print i

      ibm_db.rollback(conn)
      print "Done"
    except:
      print "SQLSTATE: %s" % ibm_db.stmt_error(stmt)
      print "Message: %s" % ibm_db.stmt_errormsg(stmt)

    try:
        stmt = ibm_db.prepare(conn, "SELECT breed, name FROM animals WHERE id = ?")
        res = ibm_db.execute(stmt, (128,))
        row = ibm_db.fetch_assoc(stmt)
        if (row):
            for i in row:
                print i
        print res
        print "SQLSTATE: %s" % ibm_db.stmt_error(stmt)
        print "Message: %s" % ibm_db.stmt_errormsg(stmt)
    except:
        print "An Exception is not expected"
        print "SQLSTATE: %s" % ibm_db.stmt_error(stmt)
        print "Message: %s" % ibm_db.stmt_errormsg(stmt)

    ibm_db.rollback(conn)
    print "Done"

#__END__
#__LUW_EXPECTED__
#Starting test ...
#
#SQLSTATE: 22001
#Message: [IBM][CLI Driver] CLI0109E  String data right truncation. SQLSTATE=22001 SQLCODE=-99999
#True
#SQLSTATE: 02000
#Message: [IBM][CLI Driver][DB2/%s] SQL0100W  No row was found for FETCH, UPDATE or DELETE; or the result of a query is an empty table.  SQLSTATE=02000 SQLCODE=100
#Done
#__ZOS_EXPECTED__
#Starting test ...
#
#SQLSTATE: 22001
#Message: [IBM][CLI Driver] CLI0109E  String data right truncation. SQLSTATE=22001 SQLCODE=-99999
#True
#SQLSTATE: 02000
#Message: [IBM][CLI Driver][DB2] SQL0100W  No row was found for FETCH, UPDATE or DELETE; or the result of a query is an empty table.  SQLSTATE=02000 SQLCODE=100
#Done
#__SYSTEMI_EXPECTED__
#Starting test ...
#
#SQLSTATE: 22001
#Message: [IBM][CLI Driver] CLI0109E  String data right truncation. SQLSTATE=22001 SQLCODE=-99999
#True
#SQLSTATE: 02000
#Message: [IBM][CLI Driver][AS] SQL0100W  No row was found for FETCH, UPDATE or DELETE; or the result of a query is an empty table.  SQLSTATE=02000 SQLCODE=100
#Done
#__IDS_EXPECTED__
#Starting test ...
#None
#SQLSTATE: 22001
#Message: [IBM][CLI Driver][IDS%s] Value exceeds string column length.
#True
#SQLSTATE: 02000
#Message: [IBM][CLI Driver][IDS%s] SQL0100W  No row was found for FETCH, UPDATE or DELETE; or the result of a query is an empty table.  SQLSTATE=02000
#Done


# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_6792_FieldTypeRetStrDatetimeTimestamp(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_6792)

  def run_test_6792(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    if conn:
      drop = 'DROP TABLE table_6792'
      result = ''
      try:
        result = ibm_db.exec_immediate(conn, drop)
      except:
        pass

      server = ibm_db.server_info( conn )
      if (server.DBMS_NAME[0:3] == 'IDS'):
        statement = "CREATE TABLE table_6792 (col1 DATETIME HOUR TO SECOND, col2 DATE, col3 DATETIME YEAR TO SECOND)"
        result = ibm_db.exec_immediate(conn, statement)
        statement = "INSERT INTO table_6792 (col1, col2, col3) values ('10:42:34', '1981-07-08', '1981-07-08 10:42:34')"
        result = ibm_db.exec_immediate(conn, statement)
      else:
        statement = "CREATE TABLE table_6792 (col1 TIME, col2 DATE, col3 TIMESTAMP)"
        result = ibm_db.exec_immediate(conn, statement)
        statement = "INSERT INTO table_6792 (col1, col2, col3) values ('10.42.34', '1981-07-08', '1981-07-08-10.42.34')"
        result = ibm_db.exec_immediate(conn, statement)

      statement = "SELECT * FROM table_6792"
      result = ibm_db.exec_immediate(conn, statement)
      
      for i in range(0, ibm_db.num_fields(result)):
        print str(i) + ":" + ibm_db.field_type(result,i)

      statement = "SELECT * FROM table_6792"
      stmt = ibm_db.prepare(conn, statement)
      rc = ibm_db.execute(stmt)
      result = ibm_db.fetch_row(stmt)
      while ( result ):
        row0 = ibm_db.result(stmt, 0)
        row1 = ibm_db.result(stmt, 1)
        row2 = ibm_db.result(stmt, 2)
        print row0
        print row1
        print row2
        result = ibm_db.fetch_row(stmt)
      
      ibm_db.close(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#0:time
#1:date
#2:timestamp
#10:42:34
#1981-07-08
#1981-07-08 10:42:34.000000
#__ZOS_EXPECTED__
#0:time
#1:date
#2:timestamp
#10:42:34
#1981-07-08
#1981-07-08 10:42:34.000000
#__SYSTEMI_EXPECTED__
#0:time
#1:date
#2:timestamp
#10:42:34
#1981-07-08
#1981-07-08 10:42:34.000000
#__IDS_EXPECTED__
#0:time
#1:date
#2:timestamp
#10:42:34
#1981-07-08
#1981-07-08 10:42:34.000000



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_300_ServerInfo(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_300)

  def run_test_300(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    server = ibm_db.server_info(conn)
    
    if server:
      print "DBMS_NAME: string(%d) \"%s\"" % (len(server.DBMS_NAME), server.DBMS_NAME)
      print "DBMS_VER: string(%d) \"%s\"" % (len(server.DBMS_VER), server.DBMS_VER)
      print "DB_CODEPAGE: int(%d)" % server.DB_CODEPAGE
      print "DB_NAME: string(%d) \"%s\"" % (len(server.DB_NAME), server.DB_NAME)
      print "INST_NAME: string(%d) \"%s\"" % (len(server.INST_NAME), server.INST_NAME)
      print "SPECIAL_CHARS: string(%d) \"%s\"" % (len(server.SPECIAL_CHARS), server.SPECIAL_CHARS)
      print "KEYWORDS: int(%d)" % len(server.KEYWORDS)
      print "DFT_ISOLATION: string(%d) \"%s\"" % (len(server.DFT_ISOLATION), server.DFT_ISOLATION)
      il = ''
      for opt in server.ISOLATION_OPTION:
        il += opt + " "
      print "ISOLATION_OPTION: string(%d) \"%s\"" % (len(il), il)
      print "SQL_CONFORMANCE: string(%d) \"%s\"" % (len(server.SQL_CONFORMANCE), server.SQL_CONFORMANCE)
      print "PROCEDURES:", server.PROCEDURES
      print "IDENTIFIER_QUOTE_CHAR: string(%d) \"%s\"" % (len(server.IDENTIFIER_QUOTE_CHAR), server.IDENTIFIER_QUOTE_CHAR)
      print "LIKE_ESCAPE_CLAUSE:", server.LIKE_ESCAPE_CLAUSE
      print "MAX_COL_NAME_LEN: int(%d)" % server.MAX_COL_NAME_LEN
      print "MAX_ROW_SIZE: int(%d)" % server.MAX_ROW_SIZE
      print "MAX_IDENTIFIER_LEN: int(%d)" % server.MAX_IDENTIFIER_LEN
      print "MAX_INDEX_SIZE: int(%d)" % server.MAX_INDEX_SIZE
      print "MAX_PROC_NAME_LEN: int(%d)" % server.MAX_PROC_NAME_LEN
      print "MAX_SCHEMA_NAME_LEN: int(%d)" % server.MAX_SCHEMA_NAME_LEN
      print "MAX_STATEMENT_LEN: int(%d)" % server.MAX_STATEMENT_LEN
      print "MAX_TABLE_NAME_LEN: int(%d)" % server.MAX_TABLE_NAME_LEN
      print "NON_NULLABLE_COLUMNS:", server.NON_NULLABLE_COLUMNS
    
      ibm_db.close(conn)
    else:
      print "Error."

#__END__
#__LUW_EXPECTED__
#DBMS_NAME: string(%d) %s
#DBMS_VER: string(%d) %s
#DB_CODEPAGE: int(%d)
#DB_NAME: string(%d) %s
#INST_NAME: string(%d) %s
#SPECIAL_CHARS: string(%d) %s
#KEYWORDS: int(%d)
#DFT_ISOLATION: string(%d) %s
#ISOLATION_OPTION: string(%d) %s
#SQL_CONFORMANCE: string(%d) %s
#PROCEDURES: %s
#IDENTIFIER_QUOTE_CHAR: string(%d) %s
#LIKE_ESCAPE_CLAUSE: %s
#MAX_COL_NAME_LEN: int(%d)
#MAX_ROW_SIZE: int(%d)
#MAX_IDENTIFIER_LEN: int(%d)
#MAX_INDEX_SIZE: int(%d)
#MAX_PROC_NAME_LEN: int(%d)
#MAX_SCHEMA_NAME_LEN: int(%d)
#MAX_STATEMENT_LEN: int(%d)
#MAX_TABLE_NAME_LEN: int(%d)
#NON_NULLABLE_COLUMNS: %s
#__ZOS_EXPECTED__
#DBMS_NAME: string(%d) %s
#DBMS_VER: string(%d) %s
#DB_CODEPAGE: int(%d)
#DB_NAME: string(%d) %s
#INST_NAME: string(%d) %s
#SPECIAL_CHARS: string(%d) %s
#KEYWORDS: int(%d)
#DFT_ISOLATION: string(%d) %s
#ISOLATION_OPTION: string(%d) %s
#SQL_CONFORMANCE: string(%d) %s
#PROCEDURES: %s
#IDENTIFIER_QUOTE_CHAR: string(%d) %s
#LIKE_ESCAPE_CLAUSE: %s
#MAX_COL_NAME_LEN: int(%d)
#MAX_ROW_SIZE: int(%d)
#MAX_IDENTIFIER_LEN: int(%d)
#MAX_INDEX_SIZE: int(%d)
#MAX_PROC_NAME_LEN: int(%d)
#MAX_SCHEMA_NAME_LEN: int(%d)
#MAX_STATEMENT_LEN: int(%d)
#MAX_TABLE_NAME_LEN: int(%d)
#NON_NULLABLE_COLUMNS: %s
#__SYSTEMI_EXPECTED__
#DBMS_NAME: string(%d) %s
#DBMS_VER: string(%d) %s
#DB_CODEPAGE: int(%d)
#DB_NAME: string(%d) %s
#INST_NAME: string(%d) %s
#SPECIAL_CHARS: string(%d) %s
#KEYWORDS: int(%d)
#DFT_ISOLATION: string(%d) %s
#ISOLATION_OPTION: string(%d) %s
#SQL_CONFORMANCE: string(%d) %s
#PROCEDURES: %s
#IDENTIFIER_QUOTE_CHAR: string(%d) %s
#LIKE_ESCAPE_CLAUSE: %s
#MAX_COL_NAME_LEN: int(%d)
#MAX_ROW_SIZE: int(%d)
#MAX_IDENTIFIER_LEN: int(%d)
#MAX_INDEX_SIZE: int(%d)
#MAX_PROC_NAME_LEN: int(%d)
#MAX_SCHEMA_NAME_LEN: int(%d)
#MAX_STATEMENT_LEN: int(%d)
#MAX_TABLE_NAME_LEN: int(%d)
#NON_NULLABLE_COLUMNS: %s
#__IDS_EXPECTED__
#DBMS_NAME: string(%d) %s
#DBMS_VER: string(%d) %s
#DB_CODEPAGE: int(%d)
#DB_NAME: string(%d) %s
#INST_NAME: string(%d) %s
#SPECIAL_CHARS: string(%d) %s
#KEYWORDS: int(%d)
#DFT_ISOLATION: string(%d) %s
#ISOLATION_OPTION: string(%d) %s
#SQL_CONFORMANCE: string(%d) %s
#PROCEDURES: %s
#IDENTIFIER_QUOTE_CHAR: string(%d) %s
#LIKE_ESCAPE_CLAUSE: %s
#MAX_COL_NAME_LEN: int(%d)
#MAX_ROW_SIZE: int(%d)
#MAX_IDENTIFIER_LEN: int(%d)
#MAX_INDEX_SIZE: int(%d)
#MAX_PROC_NAME_LEN: int(%d)
#MAX_SCHEMA_NAME_LEN: int(%d)
#MAX_STATEMENT_LEN: int(%d)
#MAX_TABLE_NAME_LEN: int(%d)
#NON_NULLABLE_COLUMNS: %s



# 
#	Licensed Materials - Property of IBM
#
#	(c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

	def test_trusted_context_pconnect(self):
		obj = IbmDbTestFunctions()
		obj.assert_expectf(self.run_test_trusted_context_pconnect)

	def run_test_trusted_context_pconnect(self):
		sql_drop_role = "DROP ROLE role_01"
		sql_create_role = "CREATE ROLE role_01"

		sql_drop_trusted_context = "DROP TRUSTED CONTEXT ctx"

		sql_create_trusted_context = "CREATE TRUSTED CONTEXT ctx BASED UPON CONNECTION USING SYSTEM AUTHID "
		sql_create_trusted_context += config.auth_user
		sql_create_trusted_context += " ATTRIBUTES (ADDRESS '"
		sql_create_trusted_context += config.hostname
		sql_create_trusted_context += "') DEFAULT ROLE role_01 ENABLE WITH USE FOR "
		sql_create_trusted_context += config.tc_user

		sql_drop_table = "DROP TABLE trusted_table"
		sql_create_table = "CREATE TABLE trusted_table (i1 int, i2 int)"

		sql_select = "SELECT * FROM trusted_table"

		# Setting up database.
		conn = ibm_db.connect(config.database, config.user, config.password)
		if conn:
			sql_grant_permission = "GRANT INSERT ON TABLE trusted_table TO ROLE role_01"
			sql_create_trusted_context_01 = sql_create_trusted_context + " WITH AUTHENTICATION"
			try:
				result = ibm_db.exec_immediate(conn, sql_drop_trusted_context)
			except:
				pass
			try:
				result = ibm_db.exec_immediate(conn, sql_drop_table)
			except:
				pass
			try:
				result = ibm_db.exec_immediate(conn, sql_drop_role)
			except:
				pass
			try:
				result = ibm_db.exec_immediate(conn, sql_create_role)
			except:
				pass
			try:
				result = ibm_db.exec_immediate(conn, sql_create_table)
			except:
				pass
			try:
				result = ibm_db.exec_immediate(conn, sql_grant_permission)
			except:
				pass
			try:
				result = ibm_db.exec_immediate(conn, sql_create_trusted_context_01)
			except:
				pass
				
			# Populate the trusted_table
			values = (\
				(10, 20),\
				(20, 40),\
			)
			sql_insert = 'INSERT INTO trusted_table (i1, i2) VALUES (?, ?)'
			stmt = ibm_db.prepare(conn, sql_insert)
			if stmt:
				for value in values:
					result = ibm_db.execute(stmt, value)
			ibm_db.close(conn)
		else:
			print "Connection failed."

		options = {ibm_db.SQL_ATTR_USE_TRUSTED_CONTEXT:	ibm_db.SQL_TRUE}
		tc_options = {ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID: config.tc_user, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_PASSWORD: config.tc_pass}
		dsn = "DATABASE=%s;HOSTNAME=%s;PORT=%d;PROTOCOL=TCPIP;UID=%s;PWD=%s;" % (config.database, config.hostname, config.port, config.auth_user, config.auth_pass)

		# Making trusted connection and performing normal operations.
		tc_conn = ibm_db.pconnect(dsn, "", "", options)
		if tc_conn:
			print "Trusted connection succeeded."
			val = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_USE_TRUSTED_CONTEXT, 1)
			if val:
				userBefore = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID, 1)
				ibm_db.set_option(tc_conn, tc_options, 1)
				userAfter = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID, 1)
				if userBefore != userAfter:
					print "User has been switched."
					
					# Inserting into table using trusted_user.
					sql_insert = "INSERT INTO " + config.user + ".trusted_table (i1, i2) VALUES (?, ?)"
					stmt = ibm_db.prepare(tc_conn, sql_insert)
					result = ibm_db.execute(stmt, (300, 500))
					
					# Updating table using trusted_user.
					sql_update = "UPDATE " + config.user + ".trusted_table set i1 = 400 WHERE i2 = 500"
					try:
						stmt = ibm_db.exec_immediate(tc_conn, sql_update)
					except:
						print ibm_db.stmt_errormsg()
			ibm_db.close(tc_conn)
		else:
			print "Trusted connection failed."

		# Creating 10 Persistance connections and checking if trusted context is enabled (Cataloged connections)
		for i in xrange(10):
			tc_conn = ibm_db.pconnect(dsn, "", "")
			if tc_conn:
				val = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_USE_TRUSTED_CONTEXT, 1)
				if val:
					userAfter = ibm_db.get_option(tc_conn, ibm_db.SQL_ATTR_TRUSTED_CONTEXT_USERID, 1)
					if userBefore != userAfter:
						print "Explicit Trusted Connection succeeded."

		# Cleaning up database.
		conn = ibm_db.connect(config.database, config.user, config.password)

		if conn:
			print "Connection succeeded."

			try:
				result = ibm_db.exec_immediate(conn, sql_drop_trusted_context)
			except:
				pass
			try:
				result = ibm_db.exec_immediate(conn, sql_drop_table)
			except:
				pass
			try:
				result = ibm_db.exec_immediate(conn, sql_drop_role)
			except:
				pass
			ibm_db.close(conn)
		else:
			print "Connection failed."
#__END__
#__LUW_EXPECTED__
#Trusted connection succeeded.
#User has been switched.
#[%s][%s][%s] SQL0551N  "%s" does not have the %s privilege to perform operation "UPDATE" on object "%s.TRUSTED_TABLE".  SQLSTATE=42501 SQLCODE=-551
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Connection succeeded.
#__ZOS_EXPECTED__
#Trusted connection succeeded.
#User has been switched.
#[%s][%s][%s] SQL0551N  "%s" does not have the %s privilege to perform operation "UPDATE" on object "%s.TRUSTED_TABLE".  SQLSTATE=42501 SQLCODE=-551
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Connection succeeded.
#__SYSTEMI_EXPECTED__
#Trusted connection succeeded.
#User has been switched.
#[%s][%s][%s] SQL0551N  "%s" does not have the privilege to perform operation "UPDATE" on object "%s.TRUSTED_TABLE".  SQLSTATE=42501 SQLCODE=-551
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Connection succeeded.
#__IDS_EXPECTED__
#Trusted connection succeeded.
#User has been switched.
#[%s][%s][%s] SQL0551N  "%s" does not have the %s privilege to perform operation "UPDATE" on object "%s.TRUSTED_TABLE".  SQLSTATE=42501 SQLCODE=-551
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Explicit Trusted Connection succeeded.
#Connection succeeded.



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_071_CloseSuccess(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_071)

  def run_test_071(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    if conn:
      rc = ibm_db.close(conn)
      if (rc == True):
        print "ibm_db.close succeeded"
      else:
        print "ibm_db.close FAILED\n"
    else:
      print "%s" % ibm_db.conn_errormsg()
      print ",sqlstate=%s" % ibm_db.conn_error()
      print "%s" % ibm_db.conn_errormsg()
      print "%s" % ibm_db.conn_errormsg()
      print "%s" % ibm_db.conn_errormsg()
      print "%s" % ibm_db.conn_errormsg()

#__END__
#__LUW_EXPECTED__
#ibm_db.close succeeded
#__ZOS_EXPECTED__
#ibm_db.close succeeded
#__SYSTEMI_EXPECTED__
#ibm_db.close succeeded
#__IDS_EXPECTED__
#ibm_db.close succeeded



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_146_CallSPINAndOUTParams(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_146)

  def run_test_146(self):      
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )
    
    if conn:
      name = "Peaches"
      second_name = "Rickety Ride"
      weight = 0
    
      print "Values of bound parameters _before_ CALL:"
      print "  1: %s 2: %s 3: %d\n" % (name, second_name, weight)
      
      stmt, name, second_name, weight = ibm_db.callproc(conn, 'match_animal', (name, second_name, weight))
    
      if stmt is not None:
        print "Values of bound parameters _after_ CALL:"
        print "  1: %s 2: %s 3: %d\n" % (name, second_name, weight)

        if (server.DBMS_NAME[0:3] != 'IDS'):
          print "Results:"
          row = ibm_db.fetch_tuple(stmt)
          while ( row ): 
            print "  %s, %s, %s" % (row[0].strip(), row[1].strip(), row[2])
            row = ibm_db.fetch_tuple(stmt)

#__END__
#__LUW_EXPECTED__
#Values of bound parameters _before_ CALL:
#  1: Peaches 2: Rickety Ride 3: 0
#
#Values of bound parameters _after_ CALL:
#  1: Peaches 2: TRUE 3: 12
#
#Results:
#  Peaches, dog, 12.30
#  Pook, cat, 3.20
#  Rickety Ride, goat, 9.70
#  Smarty, horse, 350.00
#  Sweater, llama, 150.00
#__ZOS_EXPECTED__
#Values of bound parameters _before_ CALL:
#  1: Peaches 2: Rickety Ride 3: 0
#
#Values of bound parameters _after_ CALL:
#  1: Peaches 2: TRUE 3: 12
#
#Results:
#  Peaches, dog, 12.30
#  Pook, cat, 3.20
#  Rickety Ride, goat, 9.70
#  Smarty, horse, 350.00
#  Sweater, llama, 150.00
#__SYSTEMI_EXPECTED__
#Values of bound parameters _before_ CALL:
#  1: Peaches 2: Rickety Ride 3: 0
#
#Values of bound parameters _after_ CALL:
#  1: Peaches 2: TRUE 3: 12
#
#Results:
#  Peaches, dog, 12.30
#  Pook, cat, 3.20
#  Rickety Ride, goat, 9.70
#  Smarty, horse, 350.00
#  Sweater, llama, 150.00
#__IDS_EXPECTED__
#Values of bound parameters _before_ CALL:
#  1: Peaches 2: Rickety Ride 3: 0
#
#Values of bound parameters _after_ CALL:
#  1: Peaches 2: TRUE 3: 12
#



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_201_MultipleRsltsetsDiffColDefs(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_201)

  def run_test_201(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    serverinfo = ibm_db.server_info( conn )
    server = serverinfo.DBMS_NAME[0:3]
    if (server == 'IDS'):
        procedure = """CREATE FUNCTION multiResults ()
           RETURNING CHAR(16), INT, VARCHAR(32), NUMERIC(7,2);
           
           DEFINE p_name CHAR(16);
           DEFINE p_id INT;
           DEFINE p_breed VARCHAR(32);
           DEFINE p_weight NUMERIC(7,2);
           
           FOREACH c1 FOR
              SELECT name, id, breed, weight
              INTO p_name, p_id, p_breed, p_weight
              FROM animals
              ORDER BY name DESC
              RETURN p_name, p_id, p_breed, p_weight WITH RESUME;
           END FOREACH;
    
       END FUNCTION;"""
    else:
        procedure = """CREATE PROCEDURE multiResults ()
        RESULT SETS 3
        LANGUAGE SQL
        BEGIN
         DECLARE c1 CURSOR WITH RETURN FOR
          SELECT name, id
          FROM animals
          ORDER BY name;
    
         DECLARE c2 CURSOR WITH RETURN FOR
          SELECT name, id, breed, weight
          FROM animals
          ORDER BY name DESC;
    
         DECLARE c3 CURSOR WITH RETURN FOR
          SELECT name
          FROM animals
          ORDER BY name;
    
         OPEN c1;
         OPEN c2;
         OPEN c3;
        END"""
    
    if conn:
        try:
            ibm_db.exec_immediate(conn, 'DROP PROCEDURE multiResults')
        except:
            pass
        ibm_db.exec_immediate(conn, procedure)
        stmt = ibm_db.exec_immediate(conn, 'CALL multiResults()')
    
        print "Fetching first result set"
        row = ibm_db.fetch_tuple(stmt)
        while ( row ):
           for i in row:
                print str(i).strip()
           row = ibm_db.fetch_tuple(stmt)
    
        if (server == 'IDS') :
           print "Fetching second result set (should fail -- IDS does not support multiple result sets)"
        else:
           print "Fetching second result set"
        res = ibm_db.next_result(stmt)
      
        if res:
           row = ibm_db.fetch_tuple(res)
           while ( row ):
                for i in row:
                   print str(i).strip()
                row = ibm_db.fetch_tuple(res)
     
        if (server == 'IDS'):
           print "Fetching third result set (should fail -- IDS does not support multiple result sets)"
        else:
           print "Fetching third result set"
        res2 = ibm_db.next_result(stmt)
        if res2:
           row = ibm_db.fetch_tuple(res2)
           while ( row ):
               for i in row: 
                   print str(i).strip()
               row = ibm_db.fetch_tuple(res2)
        
        ibm_db.close(conn)
    else:
       print "Connection failed."

#__END__
#__LUW_EXPECTED__
#Fetching first result set
#Bubbles
#3
#Gizmo
#4
#Peaches
#1
#Pook
#0
#Rickety Ride
#5
#Smarty
#2
#Sweater
#6
#Fetching second result set
#Sweater
#6
#llama
#150.00
#Smarty
#2
#horse
#350.00
#Rickety Ride
#5
#goat
#9.70
#Pook
#0
#cat
#3.20
#Peaches
#1
#dog
#12.30
#Gizmo
#4
#budgerigar
#0.20
#Bubbles
#3
#gold fish
#0.10
#Fetching third result set
#Bubbles
#Gizmo
#Peaches
#Pook
#Rickety Ride
#Smarty
#Sweater
#__ZOS_EXPECTED__
#Fetching first result set
#Bubbles
#3
#Gizmo
#4
#Peaches
#1
#Pook
#0
#Rickety Ride
#5
#Smarty
#2
#Sweater
#6
#Fetching second result set
#Sweater
#6
#llama
#150.00
#Smarty
#2
#horse
#350.00
#Rickety Ride
#5
#goat
#9.70
#Pook
#0
#cat
#3.20
#Peaches
#1
#dog
#12.30
#Gizmo
#4
#budgerigar
#0.20
#Bubbles
#3
#gold fish
#0.10
#Fetching third result set
#Bubbles
#Gizmo
#Peaches
#Pook
#Rickety Ride
#Smarty
#Sweater
#__SYSTEMI_EXPECTED__
#Fetching first result set
#Bubbles
#3
#Gizmo
#4
#Peaches
#1
#Pook
#0
#Rickety Ride
#5
#Smarty
#2
#Sweater
#6
#Fetching second result set
#Sweater
#6
#llama
#150.00
#Smarty
#2
#horse
#350.00
#Rickety Ride
#5
#goat
#9.70
#Pook
#0
#cat
#3.20
#Peaches
#1
#dog
#12.30
#Gizmo
#4
#budgerigar
#0.20
#Bubbles
#3
#gold fish
#0.10
#Fetching third result set
#Bubbles
#Gizmo
#Peaches
#Pook
#Rickety Ride
#Smarty
#Sweater
#__IDS_EXPECTED__
#Fetching first result set
#Sweater
#6
#llama
#150.00
#Smarty
#2
#horse
#350.00
#Rickety Ride
#5
#goat
#9.70
#Pook
#0
#cat
#3.20
#Peaches
#1
#dog
#12.30
#Gizmo
#4
#budgerigar
#0.20
#Bubbles
#3
#gold fish
#0.10
#Fetching second result set (should fail -- IDS does not support multiple result sets)
#Fetching third result set (should fail -- IDS does not support multiple result sets)



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_261_FetchObjectAccess(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_261)

  def run_test_261(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    server = ibm_db.server_info( conn )
    if (server.DBMS_NAME[0:3] == 'IDS'):
      op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
      ibm_db.set_option(conn, op, 0)

    if (server.DBMS_NAME[0:3] == 'IDS'):
      sql = "SELECT breed, TRIM(TRAILING FROM name) AS name FROM animals WHERE id = ?"
    else:
      sql = "SELECT breed, RTRIM(name) AS name FROM animals WHERE id = ?"

    if conn:
      stmt = ibm_db.prepare(conn, sql)
      ibm_db.execute(stmt, (0,))

#      NOTE: This is a workaround
#      function fetch_object() to be implemented...
#      pet = ibm_db.fetch_object(stmt)
#      while (pet):
#          print "Come here, %s, my little %s!" % (pet.NAME, pet.BREED)
#          pet = ibm_db.fetch_object(stmt)
      
      class Pet:
          pass
      
      data = ibm_db.fetch_assoc(stmt)
      while ( data ):
         pet = Pet()
         pet.NAME = data['NAME']
         pet.BREED = data['BREED']
         print "Come here, %s, my little %s!" % (pet.NAME, pet.BREED)
         data = ibm_db.fetch_assoc(stmt)
         
      ibm_db.close(conn)
      
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#Come here, Pook, my little cat!
#__ZOS_EXPECTED__
#Come here, Pook, my little cat!
#__SYSTEMI_EXPECTED__
#Come here, Pook, my little cat!
#__IDS_EXPECTED__
#Come here, Pook, my little cat!



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
    def test_execute_many(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_execute_many)

    def run_test_execute_many(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            # Drop the tabmany table, in case it exists
            drop = "DROP TABLE TABMANY"
            try:
                result = ibm_db.exec_immediate(conn, drop)
            except:
                pass

            #create table tabmany
            create = "CREATE TABLE TABMANY(id SMALLINT NOT NULL, name VARCHAR(32))"
            ibm_db.exec_immediate(conn, create)
            
            #Populate the tabmany table with execute_many
            insert = "INSERT INTO TABMANY (id, name) VALUES(?, ?)"
            params = ((10, 'Sanders'), (20, 'Pernal'), (30, 'Marenghi'), (40, 'OBrien'))
            stmt_insert = ibm_db.prepare(conn, insert)
            ibm_db.execute_many(stmt_insert, params)
            #check the number of rows inserted
            row_count = ibm_db.num_rows(stmt_insert)
            print row_count
            
            # chaeck the inserted columns
            select = "SELECT * FROM TABMANY"
            stmt_select = ibm_db.exec_immediate(conn, select)
            cols = ibm_db.fetch_tuple( stmt_select )
            while( cols ):
                print "%s, %s" % (cols[0], cols[1])
                cols = ibm_db.fetch_tuple( stmt_select )
            
            #populate the tabmany table 
            params = ((50, 'Hanes'), (55, ), (55.5, 'invalid row'), (60, 'Quigley'), (70, None) )
            try:
                ibm_db.execute_many(stmt_insert, params)
            except Exception, inst:
                #check the no. of inserted rows
                row_count = ibm_db.num_rows(stmt_insert)
                #check the exception raised by execute_many API
                print inst
                print row_count
            ibm_db.close(conn)

        else:
            print ibm_db.conn_errormsg()

#__END__
#__LUW_EXPECTED__
#4
#10, Sanders
#20, Pernal
#30, Marenghi
#40, OBrien
#Error 1: Value parameter tuple: 2 has less no of param 
#Error 2: Value parameters array 3 is not homogeneous with privious parameters array 
#3
#__ZOS_EXPECTED__
#4
#10, Sanders
#20, Pernal
#30, Marenghi
#40, OBrien
#Error 1: Value parameter tuple: 2 has less no of param 
#Error 2: Value parameters array 3 is not homogeneous with privious parameters array 
#3



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_090_ConnmsgWrongDbAlias(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_090)

  def run_test_090(self):
    try:
      conn = ibm_db.connect("x", config.user, config.password)
      print "??? No way."
    except:
      err = ibm_db.conn_errormsg()
      print err

#__END__
#__LUW_EXPECTED__
#[IBM][CLI Driver] SQL1013N  The database alias name or database name "X" could not be found.  SQLSTATE=42705 SQLCODE=-1013
#__ZOS_EXPECTED__
#[IBM][CLI Driver] SQL1013N  The database alias name or database name "X" could not be found.  SQLSTATE=42705 SQLCODE=-1013
#__SYSTEMI_EXPECTED__
#[IBM][CLI Driver] SQL1013N  The database alias name or database name "X" could not be found.  SQLSTATE=42705 SQLCODE=-1013
#__IDS_EXPECTED__
#[IBM][CLI Driver] SQL1013N  The database alias name or database name "X" could not be found.  SQLSTATE=42705 SQLCODE=-1013



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_213_FieldDisplaySize_04(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_213)

  def run_test_213(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    result = ibm_db.exec_immediate(conn, "select * from sales")
    
    i = "sales_person"
    
    print "%s size %d\n" % (i, (ibm_db.field_display_size(result,i) or 0))
    
    i = "REGION"
    
    print "%s size %d\n" % (i, (ibm_db.field_display_size(result,i) or 0))
    
    i = "REgion"
    
    print "%s size %d\n" % (i, (ibm_db.field_display_size(result,i) or 0))
    
    i = "HELMUT"
    
    print "%s size %d\n" % (i, (ibm_db.field_display_size(result,i) or 0))
    
    t = ibm_db.field_display_size(result,"")
    
    print t
    
    t = ibm_db.field_display_size(result,"HELMUT")
    
    print t
    
    t = ibm_db.field_display_size(result,"Region")
    
    print t
    
    t = ibm_db.field_display_size(result,"SALES_DATE")
    
    print t

#__END__
#__LUW_EXPECTED__
#sales_person size 0
#REGION size 15
#REgion size 0
#HELMUT size 0
#False
#False
#False
#10
#__ZOS_EXPECTED__
#sales_person size 0
#REGION size 15
#REgion size 0
#HELMUT size 0
#False
#False
#False
#10
#__SYSTEMI_EXPECTED__
#sales_person size 0
#REGION size 15
#REgion size 0
#HELMUT size 0
#False
#False
#False
#10
#__IDS_EXPECTED__
#sales_person size 15
#REGION size 0
#REgion size 0
#HELMUT size 0
#False
#False
#False
#False



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_062_Tables_03(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_062)

  def run_test_062(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    create = 'CREATE SCHEMA AUTHORIZATION t'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t1( c1 integer, c2 varchar(40))'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t2( c1 integer, c2 varchar(40))'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t3( c1 integer, c2 varchar(40))'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t4( c1 integer, c2 varchar(40))'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
    
    if conn:
      schema = 'T'
      result = ibm_db.tables(conn,None,schema);    
      i = 0
      row = ibm_db.fetch_both(result)
      while ( row ):
        str = row[1] + "/" + row[2] + "/" + row[3]
        if (i < 4):
          print str
        i = i + 1
        row = ibm_db.fetch_both(result)

      ibm_db.exec_immediate(conn, 'DROP TABLE t.t1')
      ibm_db.exec_immediate(conn, 'DROP TABLE t.t2')
      ibm_db.exec_immediate(conn, 'DROP TABLE t.t3')
      ibm_db.exec_immediate(conn, 'DROP TABLE t.t4')

      print "done!"
    else:
      print "no connection: #{ibm_db.conn_errormsg}";    

#__END__
#__LUW_EXPECTED__
#T/T1/TABLE
#T/T2/TABLE
#T/T3/TABLE
#T/T4/TABLE
#done!
#__ZOS_EXPECTED__
#T/T1/TABLE
#T/T2/TABLE
#T/T3/TABLE
#T/T4/TABLE
#done!
#__SYSTEMI_EXPECTED__
#T/T1/TABLE
#T/T2/TABLE
#T/T3/TABLE
#T/T4/TABLE
#done!
#__IDS_EXPECTED__
#T%s/t1/TABLE%s
#T%s/t2/TABLE%s
#T%s/t3/TABLE%s
#T%s/t4/TABLE%s
#done!



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_230_FieldTypePos(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_230)

  def run_test_230(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    result = ibm_db.exec_immediate(conn, "select * from sales")
    result2 = ibm_db.exec_immediate(conn, "select * from staff")
    result3 = ibm_db.exec_immediate(conn, "select * from emp_photo")
    
    for i in range(0, ibm_db.num_fields(result) + 1):
      print str(i) + ":" + str(ibm_db.field_type(result,i))
    
    print "\n-----"
    
    for i in range(0, ibm_db.num_fields(result2)):
      print str(i) + ":" + str(ibm_db.field_type(result2,i))
      
    print "\n-----"

    for i in range(0, 3):
      print str(i) + ":" + str(ibm_db.field_type(result3,i))

    print "\n-----"
    
    print "region:%s" % str(ibm_db.field_type(result,'region'))
    print "5:%s" % str(ibm_db.field_type(result2,5))

#__END__
#__LUW_EXPECTED__
#0:date
#1:string
#2:string
#3:int
#4:False
#
#-----
#0:int
#1:string
#2:int
#3:string
#4:int
#5:decimal
#6:decimal
#
#-----
#0:string
#1:string
#2:blob
#
#-----
#region:False
#5:decimal
#__ZOS_EXPECTED__
#0:date
#1:string
#2:string
#3:int
#4:False
#
#-----
#0:int
#1:string
#2:int
#3:string
#4:int
#5:decimal
#6:decimal
#
#-----
#0:string
#1:string
#2:blob
#
#-----
#region:False
#5:decimal
#__SYSTEMI_EXPECTED__
#0:date
#1:string
#2:string
#3:int
#4:False
#
#-----
#0:int
#1:string
#2:int
#3:string
#4:int
#5:decimal
#6:decimal
#
#-----
#0:string
#1:string
#2:blob
#
#-----
#region:False
#5:decimal
#__IDS_EXPECTED__
#0:date
#1:string
#2:string
#3:int
#4:False
#
#-----
#0:int
#1:string
#2:int
#3:string
#4:int
#5:decimal
#6:decimal
#
#-----
#0:string
#1:string
#2:blob
#
#-----
#region:string
#5:decimal



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_034_FetchAssoc(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_034)

  def run_test_034(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    server = ibm_db.server_info( conn )
    if (server.DBMS_NAME[0:3] == 'IDS'):
      op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
      ibm_db.set_option(conn, op, 0)

    result = ibm_db.exec_immediate(conn, "select * from staff")
    row = ibm_db.fetch_assoc(result)
    if( row ):
      #printf("%5d  ",row['ID'])
      #printf("%-10s ",row['NAME'])
      #printf("%5d ",row['DEPT'])
      #printf("%-7s ",row['JOB'])
      #printf("%5d ", row['YEARS'])
      #printf("%15s ", row['SALARY'])
      #printf("%10s ", row['COMM'])
      #puts ""
      print "%5d %-10s %5d %-7s %5d %15s %10s" % (row['ID'], row['NAME'], row['DEPT'], row['JOB'], row['YEARS'], row['SALARY'], row['COMM'])
    
    ibm_db.close(conn)

#__END__
#__LUW_EXPECTED__
#   10 Sanders       20 Mgr         7        18357.50       None
#__ZOS_EXPECTED__
#   10 Sanders       20 Mgr         7        18357.50       None
#__SYSTEMI_EXPECTED__
#   10 Sanders       20 Mgr         7        18357.50       None
#__IDS_EXPECTED__
#   10 Sanders       20 Mgr         7        18357.50       None



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_121_FieldNameAddCol(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_121)

  def run_test_121(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )
    
    if conn:
      ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

      insert = "INSERT INTO animals values (7, 'cat', 'Benji', 5.1)"
      ibm_db.exec_immediate(conn, insert)
        
      stmt = ibm_db.exec_immediate(conn, "SELECT breed, COUNT(breed) AS number FROM animals GROUP BY breed ORDER BY breed")
    
      name1 = ibm_db.field_name(stmt, 0)
      name2 = ibm_db.field_name(stmt, 1)
      name3 = ibm_db.field_name(stmt, 2)
      name4 = ibm_db.field_name(stmt, 3)
      
      if (server.DBMS_NAME[0:3] == 'IDS'):
        name5 = ibm_db.field_name(stmt, "breed")
        name6 = ibm_db.field_name(stmt, 7)
        name7 = ibm_db.field_name(stmt, '"nUMBER"')
        name8 = ibm_db.field_name(stmt, "number")
      else:
        name5 = ibm_db.field_name(stmt, "BREED")
        name6 = ibm_db.field_name(stmt, 7)
        name7 = ibm_db.field_name(stmt, '"Number"')
        name8 = ibm_db.field_name(stmt, "NUMBER")
      
      print "string(%d) \"%s\"" % (len(name1), name1)
      print "string(%d) \"%s\"" % (len(name2), name2)
      print "%s" % name3
      print "%s" % name4

      print "string(%d) \"%s\"" % (len(name5), name5)
      print "%s" % name6
      print "%s" % name7
      print "string(%d) \"%s\"" % (len(name8), name8)

      ibm_db.rollback(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#string(5) "BREED"
#string(6) "NUMBER"
#False
#False
#string(5) "BREED"
#False
#False
#string(6) "NUMBER"
#__ZOS_EXPECTED__
#string(5) "BREED"
#string(6) "NUMBER"
#False
#False
#string(5) "BREED"
#False
#False
#string(6) "NUMBER"
#__SYSTEMI_EXPECTED__
#string(5) "BREED"
#string(6) "NUMBER"
#False
#False
#string(5) "BREED"
#False
#False
#string(6) "NUMBER"
#__IDS_EXPECTED__
#string(5) "breed"
#string(6) "number"
#False
#False
#string(5) "breed"
#False
#False
#string(6) "number"



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_265_NoAffectedRows(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_265)

  def run_test_265(self):
    # Make a connection
    conn = ibm_db.connect(config.database, config.user, config.password)

    cursor_option = {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_STATIC}

    if conn:
      server = ibm_db.server_info( conn )
      if (server.DBMS_NAME[0:3] == 'IDS'):
         op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
         ibm_db.set_option(conn, op, 0)

      try:
        sql = 'drop table test'

        stmt = ibm_db.prepare(conn, sql)
        ibm_db.set_option(stmt, cursor_option, 0)
        ibm_db.execute(stmt)
        print "Number of affected rows: %d" % ibm_db.get_num_result(stmt)
      except:
        pass

      if ((server.DBMS_NAME[0:3] == 'IDS') or (server.DBMS_NAME[0:2] == "AS")):
        sql = "create table test(id integer, name VARCHAR(10), clob_col CLOB, some_var VARCHAR(100) )"
      else:
        sql = "create table test(id integer, name VARCHAR(10), clob_col CLOB, some_var XML )"

      stmt = ibm_db.prepare(conn, sql)
      ibm_db.set_option(stmt, cursor_option, 0)
      ibm_db.execute(stmt)
      print "Number of affected rows: %d" % ibm_db.get_num_result(stmt)

      sql = 'select id from test'

      stmt = ibm_db.prepare(conn, sql)
      ibm_db.set_option(stmt, cursor_option, 0)
      ibm_db.execute(stmt)
      print "Number of affected rows: %d" % ibm_db.get_num_result(stmt)

      sql = "insert into test values( 1, 'some', 'here is a clob value', '<?xml version=\"1.0\" encoding=\"UTF-8\" ?><test attribute=\"value\"/>')"

      stmt = ibm_db.prepare(conn, sql)
      ibm_db.set_option(stmt, cursor_option, 0)
      ibm_db.execute(stmt)
      print "Number of affected rows: %d" % ibm_db.get_num_result(stmt)

      sql = "insert into test values(2, 'value', 'clob data', NULL)"

      stmt = ibm_db.prepare(conn, sql)
      ibm_db.set_option(stmt, cursor_option, 0)
      ibm_db.execute(stmt)
      print "Number of affected rows: %d" % ibm_db.get_num_result(stmt)

      sql = "insert into test values(2, 'in varchar', 'data2', NULL)"

      stmt = ibm_db.prepare(conn, sql)
      ibm_db.set_option(stmt, cursor_option, 0)
      ibm_db.execute(stmt)
      print "Number of affected rows: %d" % ibm_db.get_num_result(stmt)

      sql = 'select * from test'

      stmt = ibm_db.prepare(conn, sql)
      ibm_db.set_option(stmt, cursor_option, 0)
      ibm_db.execute(stmt)
      print "Number of affected rows: %d" % ibm_db.get_num_result(stmt)
      row = ibm_db.fetch_tuple(stmt)
      while ( row ):
        print "%s, %s, %s, %s\n" %(row[0], row[1], row[2], ((row[3] is not None) and row[3].startswith(u'\ufeff')) and  row[3][1:] or  row[3])
        row = ibm_db.fetch_tuple(stmt)

      sql = 'select id, name from test where id = ?'

      stmt = ibm_db.prepare(conn, sql)
      ibm_db.set_option(stmt, cursor_option, 0)
      ibm_db.execute(stmt, (2,))
      print "Number of affected rows: %d" % ibm_db.get_num_result(stmt)
      row = ibm_db.fetch_tuple(stmt)
      while ( row ):
        print "%s, %s\n" %(row[0], row[1])
        row = ibm_db.fetch_tuple(stmt)

      if (server.DBMS_NAME[0:3] == 'IDS'):
        sql = "select * from test"
      else:
        sql = 'select * from test fetch first 12 rows only optimize for 12 rows'

      stmt = ibm_db.prepare(conn, sql)
      ibm_db.set_option(stmt, cursor_option, 0)
      ibm_db.num_fields(stmt)
      ibm_db.execute(stmt)
      print "Number of affected rows: %d" % ibm_db.get_num_result(stmt)
      row = ibm_db.fetch_tuple(stmt)
      while ( row ):
        print "%s, %s, %s, %s\n" %(row[0], row[1], row[2], ((row[3] is not None) and row[3].startswith(u'\ufeff')) and  row[3][1:] or  row[3])
        row = ibm_db.fetch_tuple(stmt)

      ibm_db.close(conn)

#__END__
#__LUW_EXPECTED__
#Number of affected rows: -2
#Number of affected rows: -2
#Number of affected rows: 0
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: 2
#2, value
#2, in varchar
#Number of affected rows: -1
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#__ZOS_EXPECTED__
#Number of affected rows: -2
#Number of affected rows: -2
#Number of affected rows: 0
#Number of affected rows: -2
#Number of affected rows: -1
#Number of affected rows: -2
#Number of affected rows: 0
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: 2
#2, value
#2, in varchar
#Number of affected rows: 0
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#__SYSTEMI_EXPECTED__
#Number of affected rows: -2
#Number of affected rows: -2
#Number of affected rows: 0
#Number of affected rows: -2
#Number of affected rows: -1
#Number of affected rows: -2
#Number of affected rows: 0
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: 2
#2, value
#2, in varchar
#Number of affected rows: 0
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#__IDS_EXPECTED__
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: -1
#Number of affected rows: 3
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None
#Number of affected rows: 2
#2, value
#2, in varchar
#Number of affected rows: 3
#1, some, here is a clob value, <?xml version="1.0" encoding="UTF-16" ?><test attribute="value"/>
#2, value, clob data, None
#2, in varchar, data2, None)



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_122_FieldNameDiffCaseColNames(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_122)

  def run_test_122(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    if conn:
      drop = "drop table ftest"
      try:
        ibm_db.exec_immediate( conn, drop )
      except:
        pass
      
      create = "create table ftest ( \"TEST\" integer, \"test\" integer, \"Test\" integer  )"
      ibm_db.exec_immediate(conn, create)
      
      insert = "INSERT INTO ftest values (1,2,3)"
      ibm_db.exec_immediate(conn, insert)
      
      stmt = ibm_db.exec_immediate(conn, "SELECT * FROM ftest")
    
      num1 = ibm_db.field_name(stmt, 0)
      num2 = ibm_db.field_name(stmt, 1)
      num3 = ibm_db.field_name(stmt, 2)
      
      num4 = ibm_db.field_name(stmt, "TEST")
      num5 = ibm_db.field_name(stmt, 'test')
      num6 = ibm_db.field_name(stmt, 'Test')

      print "string(%d) \"%s\"" % (len(num1), num1)
      print "string(%d) \"%s\"" % (len(num2), num2)
      print "string(%d) \"%s\"" % (len(num3), num3)

      print "string(%d) \"%s\"" % (len(num4), num4)
      print "string(%d) \"%s\"" % (len(num5), num5)
      print "string(%d) \"%s\"" % (len(num6), num6)
      
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#__ZOS_EXPECTED__
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#__SYSTEMI_EXPECTED__
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#__IDS_EXPECTED__
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_124_FieldNamePos_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_124)

  def run_test_124(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
  
    if conn:
       result = ibm_db.exec_immediate(conn, "select * from staff, employee, org where employee.lastname in ('HAAS','THOMPSON', 'KWAN', 'GEYER', 'STERN', 'PULASKI', 'HENDERSON', 'SPENSER', 'LUCCHESSI', 'OCONNELL', 'QUINTANA', 'NICHOLLS', 'ADAMSON', 'PIANKA', 'YOSHIMURA', 'SCOUTTEN', 'WALKER', 'BROWN', 'JONES', 'LUTZ', 'JEFFERSON', 'MARINO', 'SMITH', 'JOHNSON', 'PEREZ', 'SCHNEIDER', 'PARKER', 'SMITH', 'SETRIGHT', 'MEHTA', 'LEE', 'GOUNOT') order by org.location,employee.lastname,staff.id")
       cols = ibm_db.num_fields(result)
       j = 0
       row = ibm_db.fetch_both(result)
       while ( row ):
          for i in range(0, cols):
             field = ibm_db.field_name(result, i)
             value = row[ibm_db.field_name(result, i)]
             if (value == None): 
                value = ''
             print "%s:%s" % (field, value)
          print "---------"
          j += 1
          if (j == 10):
            break
       
          row = ibm_db.fetch_both(result)
       
       ibm_db.close(conn)
       print "done"
    else:
       print ibm_db.conn_errormsg()
#__END__
#__LUW_EXPECTED__
#ID:10
#NAME:Sanders
#DEPT:20
#JOB:DESIGNER
#YEARS:7
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:20
#NAME:Pernal
#DEPT:20
#JOB:DESIGNER
#YEARS:8
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:30
#NAME:Marenghi
#DEPT:38
#JOB:DESIGNER
#YEARS:5
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:40
#NAME:OBrien
#DEPT:38
#JOB:DESIGNER
#YEARS:6
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:50
#NAME:Hanes
#DEPT:15
#JOB:DESIGNER
#YEARS:10
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:60
#NAME:Quigley
#DEPT:38
#JOB:DESIGNER
#YEARS:
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:70
#NAME:Rothman
#DEPT:15
#JOB:DESIGNER
#YEARS:7
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:80
#NAME:James
#DEPT:20
#JOB:DESIGNER
#YEARS:
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:90
#NAME:Koonitz
#DEPT:42
#JOB:DESIGNER
#YEARS:6
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:100
#NAME:Plotz
#DEPT:42
#JOB:DESIGNER
#YEARS:7
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#done
#__ZOS_EXPECTED__
#ID:10
#NAME:Sanders
#DEPT:20
#JOB:DESIGNER
#YEARS:7
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:20
#NAME:Pernal
#DEPT:20
#JOB:DESIGNER
#YEARS:8
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:30
#NAME:Marenghi
#DEPT:38
#JOB:DESIGNER
#YEARS:5
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:40
#NAME:OBrien
#DEPT:38
#JOB:DESIGNER
#YEARS:6
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:50
#NAME:Hanes
#DEPT:15
#JOB:DESIGNER
#YEARS:10
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:60
#NAME:Quigley
#DEPT:38
#JOB:DESIGNER
#YEARS:
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:70
#NAME:Rothman
#DEPT:15
#JOB:DESIGNER
#YEARS:7
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:80
#NAME:James
#DEPT:20
#JOB:DESIGNER
#YEARS:
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:90
#NAME:Koonitz
#DEPT:42
#JOB:DESIGNER
#YEARS:6
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:100
#NAME:Plotz
#DEPT:42
#JOB:DESIGNER
#YEARS:7
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#done
#__SYSTEMI_EXPECTED__
#ID:10
#NAME:Sanders
#DEPT:20
#JOB:DESIGNER
#YEARS:7
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:20
#NAME:Pernal
#DEPT:20
#JOB:DESIGNER
#YEARS:8
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:30
#NAME:Marenghi
#DEPT:38
#JOB:DESIGNER
#YEARS:5
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:40
#NAME:OBrien
#DEPT:38
#JOB:DESIGNER
#YEARS:6
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:50
#NAME:Hanes
#DEPT:15
#JOB:DESIGNER
#YEARS:10
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:60
#NAME:Quigley
#DEPT:38
#JOB:DESIGNER
#YEARS:
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:70
#NAME:Rothman
#DEPT:15
#JOB:DESIGNER
#YEARS:7
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:80
#NAME:James
#DEPT:20
#JOB:DESIGNER
#YEARS:
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:90
#NAME:Koonitz
#DEPT:42
#JOB:DESIGNER
#YEARS:6
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#ID:100
#NAME:Plotz
#DEPT:42
#JOB:DESIGNER
#YEARS:7
#SALARY:25280.00
#COMM:2022.00
#EMPNO:000150
#FIRSTNME:BRUCE
#MIDINIT: 
#LASTNAME:ADAMSON
#WORKDEPT:D11
#PHONENO:4510
#HIREDATE:1972-02-12
#JOB:DESIGNER
#EDLEVEL:16
#SEX:M
#BIRTHDATE:1947-05-17
#SALARY:25280.00
#BONUS:500.00
#COMM:2022.00
#DEPTNUMB:38
#DEPTNAME:South Atlantic
#MANAGER:30
#DIVISION:Eastern
#LOCATION:Atlanta
#---------
#done
#__IDS_EXPECTED__
#id:10
#name:Sanders
#dept:20
#job:DESIGNER
#years:7
#salary:25280.00
#comm:2022.00
#empno:000150
#firstnme:BRUCE
#midinit: 
#lastname:ADAMSON
#workdept:D11
#phoneno:4510
#hiredate:1972-02-12
#job:DESIGNER
#edlevel:16
#sex:M
#birthdate:1947-05-17
#salary:25280.00
#bonus:500.00
#comm:2022.00
#deptnumb:38
#deptname:South Atlantic
#manager:30
#division:Eastern
#location:Atlanta
#---------
#id:20
#name:Pernal
#dept:20
#job:DESIGNER
#years:8
#salary:25280.00
#comm:2022.00
#empno:000150
#firstnme:BRUCE
#midinit: 
#lastname:ADAMSON
#workdept:D11
#phoneno:4510
#hiredate:1972-02-12
#job:DESIGNER
#edlevel:16
#sex:M
#birthdate:1947-05-17
#salary:25280.00
#bonus:500.00
#comm:2022.00
#deptnumb:38
#deptname:South Atlantic
#manager:30
#division:Eastern
#location:Atlanta
#---------
#id:30
#name:Marenghi
#dept:38
#job:DESIGNER
#years:5
#salary:25280.00
#comm:2022.00
#empno:000150
#firstnme:BRUCE
#midinit: 
#lastname:ADAMSON
#workdept:D11
#phoneno:4510
#hiredate:1972-02-12
#job:DESIGNER
#edlevel:16
#sex:M
#birthdate:1947-05-17
#salary:25280.00
#bonus:500.00
#comm:2022.00
#deptnumb:38
#deptname:South Atlantic
#manager:30
#division:Eastern
#location:Atlanta
#---------
#id:40
#name:OBrien
#dept:38
#job:DESIGNER
#years:6
#salary:25280.00
#comm:2022.00
#empno:000150
#firstnme:BRUCE
#midinit: 
#lastname:ADAMSON
#workdept:D11
#phoneno:4510
#hiredate:1972-02-12
#job:DESIGNER
#edlevel:16
#sex:M
#birthdate:1947-05-17
#salary:25280.00
#bonus:500.00
#comm:2022.00
#deptnumb:38
#deptname:South Atlantic
#manager:30
#division:Eastern
#location:Atlanta
#---------
#id:50
#name:Hanes
#dept:15
#job:DESIGNER
#years:10
#salary:25280.00
#comm:2022.00
#empno:000150
#firstnme:BRUCE
#midinit: 
#lastname:ADAMSON
#workdept:D11
#phoneno:4510
#hiredate:1972-02-12
#job:DESIGNER
#edlevel:16
#sex:M
#birthdate:1947-05-17
#salary:25280.00
#bonus:500.00
#comm:2022.00
#deptnumb:38
#deptname:South Atlantic
#manager:30
#division:Eastern
#location:Atlanta
#---------
#id:60
#name:Quigley
#dept:38
#job:DESIGNER
#years:
#salary:25280.00
#comm:2022.00
#empno:000150
#firstnme:BRUCE
#midinit: 
#lastname:ADAMSON
#workdept:D11
#phoneno:4510
#hiredate:1972-02-12
#job:DESIGNER
#edlevel:16
#sex:M
#birthdate:1947-05-17
#salary:25280.00
#bonus:500.00
#comm:2022.00
#deptnumb:38
#deptname:South Atlantic
#manager:30
#division:Eastern
#location:Atlanta
#---------
#id:70
#name:Rothman
#dept:15
#job:DESIGNER
#years:7
#salary:25280.00
#comm:2022.00
#empno:000150
#firstnme:BRUCE
#midinit: 
#lastname:ADAMSON
#workdept:D11
#phoneno:4510
#hiredate:1972-02-12
#job:DESIGNER
#edlevel:16
#sex:M
#birthdate:1947-05-17
#salary:25280.00
#bonus:500.00
#comm:2022.00
#deptnumb:38
#deptname:South Atlantic
#manager:30
#division:Eastern
#location:Atlanta
#---------
#id:80
#name:James
#dept:20
#job:DESIGNER
#years:
#salary:25280.00
#comm:2022.00
#empno:000150
#firstnme:BRUCE
#midinit: 
#lastname:ADAMSON
#workdept:D11
#phoneno:4510
#hiredate:1972-02-12
#job:DESIGNER
#edlevel:16
#sex:M
#birthdate:1947-05-17
#salary:25280.00
#bonus:500.00
#comm:2022.00
#deptnumb:38
#deptname:South Atlantic
#manager:30
#division:Eastern
#location:Atlanta
#---------
#id:90
#name:Koonitz
#dept:42
#job:DESIGNER
#years:6
#salary:25280.00
#comm:2022.00
#empno:000150
#firstnme:BRUCE
#midinit: 
#lastname:ADAMSON
#workdept:D11
#phoneno:4510
#hiredate:1972-02-12
#job:DESIGNER
#edlevel:16
#sex:M
#birthdate:1947-05-17
#salary:25280.00
#bonus:500.00
#comm:2022.00
#deptnumb:38
#deptname:South Atlantic
#manager:30
#division:Eastern
#location:Atlanta
#---------
#id:100
#name:Plotz
#dept:42
#job:DESIGNER
#years:7
#salary:25280.00
#comm:2022.00
#empno:000150
#firstnme:BRUCE
#midinit: 
#lastname:ADAMSON
#workdept:D11
#phoneno:4510
#hiredate:1972-02-12
#job:DESIGNER
#edlevel:16
#sex:M
#birthdate:1947-05-17
#salary:25280.00
#bonus:500.00
#comm:2022.00
#deptnumb:38
#deptname:South Atlantic
#manager:30
#division:Eastern
#location:Atlanta
#---------
#done






# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_180_StmtErrMsg(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_180)

  def run_test_180(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    if conn:
      result = ''
      result2 = ''
      try:
        result = ibm_db.exec_immediate(conn,"insert int0 t_string values(123,1.222333,'one to one')")
      except:
        pass
      if result:
        cols = ibm_db.num_fields(result)
        print "col:", cols,", " 
        rows = ibm_db.num_rows(result)
        print "affected row:", rows
      else:
        print ibm_db.stmt_errormsg()
      try:
        result = ibm_db.exec_immediate(conn,"delete from t_string where a=123")
      except:
        pass
      if result:
        cols = ibm_db.num_fields(result)
        print "col:", cols,", "
        rows = ibm_db.num_rows(result)
        print "affected row:", rows
      else:
        print ibm_db.stmt_errormsg()
    
    else:
      print "no connection"

#__END__
#__LUW_EXPECTED__
#[IBM][CLI Driver][DB2/%s] SQL0104N  An unexpected token "insert int0 t_string" was found following "BEGIN-OF-STATEMENT".  Expected tokens may include:  "<space>".  SQLSTATE=42601 SQLCODE=-104col: 0 , affected row: 0
#__ZOS_EXPECTED__
#[IBM][CLI Driver][DB2%s] SQL0104N  An unexpected token "INT0" was found following "".  Expected tokens may include:  "INTO".  SQLSTATE=42601 SQLCODE=-104col: 0 , affected row: 0
#__SYSTEMI_EXPECTED__
#[IBM][CLI Driver][AS] SQL0104N  An unexpected token "INT0" was found following "".  Expected tokens may include:  "INTO".  SQLSTATE=42601 SQLCODE=-104col: 0 , affected row: 0
#__IDS_EXPECTED__
#[IBM][CLI Driver][IDS/%s] A syntax error has occurred. SQLCODE=-201col: 0 , affected row: 0



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_080_ConnWrongDbAlias(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_080)

  def run_test_080(self):
    try:
      conn = ibm_db.connect("x", config.user, config.password)
      print "??? No way."
    except:
      print ibm_db.conn_error()
 
    #if conn:
    #  print "??? No way."
    #else:
    #  print ibm_db.conn_error()

#__END__
#__LUW_EXPECTED__
#08001
#__ZOS_EXPECTED__
#08001
#__SYSTEMI_EXPECTED__
#08001
#__IDS_EXPECTED__
#08001



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS requires that you pass the schema name (cannot pass None)

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_025_PrimaryKeys(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_025)

  def run_test_025(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )
      
    if (conn != 0):
      drop = 'DROP TABLE test_primary_keys'
      try:
        result = ibm_db.exec_immediate(conn, drop)
      except:
        pass
      drop = 'DROP TABLE test_foreign_keys'
      try:
        result = ibm_db.exec_immediate(conn, drop)
      except:
        pass
      statement = 'CREATE TABLE test_primary_keys (id INTEGER NOT NULL, PRIMARY KEY(id))'
      result = ibm_db.exec_immediate(conn, statement)
      statement = "INSERT INTO test_primary_keys VALUES (1)"
      result = ibm_db.exec_immediate(conn, statement)
      statement = 'CREATE TABLE test_foreign_keys (idf INTEGER NOT NULL, FOREIGN KEY(idf) REFERENCES test_primary_keys(id))'
      result = ibm_db.exec_immediate(conn, statement)
      statement = "INSERT INTO test_foreign_keys VALUES (1)"
      result = ibm_db.exec_immediate(conn, statement)
      
      if (server.DBMS_NAME[0:3] == 'IDS'):
        stmt = ibm_db.primary_keys(conn, None, config.user, 'test_primary_keys')
      else:
        stmt = ibm_db.primary_keys(conn, None, None, 'TEST_PRIMARY_KEYS')
      row = ibm_db.fetch_tuple(stmt)
      print row[2]
      print row[3]
      print row[4]
      ibm_db.close(conn)
    else:
      print ibm_db.conn_errormsg()
      print "Connection failed\n"

#__END__
#__LUW_EXPECTED__
#TEST_PRIMARY_KEYS
#ID
#1
#__ZOS_EXPECTED__
#TEST_PRIMARY_KEYS
#ID
#1
#__SYSTEMI_EXPECTED__
#TEST_PRIMARY_KEYS
#ID
#1
#__IDS_EXPECTED__
#test_primary_keys
#id
#1



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_048_FetchTupleBinaryData_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_048)

  def run_test_048(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    if (not conn):
      print "Could not make a connection." 
      return 0
    fp = open("tests/spook_out.png", "wb")
    result = ibm_db.exec_immediate(conn, "SELECT picture, LENGTH(picture) FROM animal_pics WHERE name = 'Spook'")
    if (not result):
      print "Could not execute SELECT statement."
      return 0
    row = ibm_db.fetch_tuple(result)
    if row:
      fp.write(row[0])
    else:
      print ibm_db.stmt_errormsg()
    fp.close()
    cmp = (open('tests/spook_out.png', "rb").read() == open('tests/spook.png', "rb").read())
    print "Are the files the same:", cmp

#__END__
#__LUW_EXPECTED__
#Are the files the same: True
#__ZOS_EXPECTED__
#Are the files the same: True
#__SYSTEMI_EXPECTED__
#Are the files the same: True
#__IDS_EXPECTED__
#Are the files the same: True



import os
import sys
import unittest
import StringIO
import re
import glob
import config

class IbmDbTest(unittest.TestCase):
  
  slash = '/'
  
  # Currently, this function serves no purpose.
  # However, this function has to be defined if the
  #   unittest.TestCase is inherited in the given class.
  # For future reference, this function is called 
  #   everytime a test is ran in this testsuite.
  def setUp(self):
    pass

  # This function gets a list of all the test files located
  #   in the current_dir/config.test_dir directory.
  def getFileList(self):
    if (sys.platform[0:3] == 'win'):
      self.slash = '\\'
    dir = config.test_dir + self.slash
    if (os.environ.get("SINGLE_PYTHON_TEST", None)):
      testfile = dir + os.environ.get("SINGLE_PYTHON_TEST", None)
      filelist = glob.glob(testfile)
    else:
      filelist = glob.glob(dir + "test_*.py")
      
    for i in range(0, len(filelist)):
      filelist[i] = filelist[i].replace('.py', '')
      filelist[i] = filelist[i].replace(config.test_dir + self.slash, '')
    filelist.sort()
    return filelist

  # This function is called to run all the tests.
  def runTest(self):
    filelist = self.getFileList();
    suite = unittest.TestSuite()
    
    sys.path = [os.path.dirname(os.path.abspath(__file__)) + self.slash + config.test_dir] + sys.path[0:]
    
    for i in range(0, len(filelist)):
      exec("import %s" % filelist[i])
      testFuncName = filelist[i].replace(config.test_dir + self.slash, '')
      exec("suite.addTest(%s.IbmDbTestCase(testFuncName))" % filelist[i])
      
    unittest.TextTestRunner(verbosity=2).run(suite) 

obj = IbmDbTest()
suite = obj.runTest()



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_005_ConnBadUserBadPwd(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_005)

  def run_test_005(self):
    baduser = "non_user"
    badpass = "invalid_password"
    dsn = "DATABASE=" + config.database + ";UID=" + baduser + ";PWD=" + badpass + ";"
    try:
      conn = ibm_db.connect(dsn, "", "")
      print "odd, ibm_db.connect succeeded with an invalid user / password"
      ibm_db.close(conn)
    except: 
      print "Ooops"

#__END__
#__LUW_EXPECTED__
#Ooops
#__ZOS_EXPECTED__
#Ooops
#__SYSTEMI_EXPECTED__
#Ooops
#__IDS_EXPECTED__
#Ooops



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS requires that you pass the schema name (cannot pass nil)
#
# NOTE: IDS will not return any rows from column_privileges unless
#       there have been privileges granted to another user other
#       then the user that is running the script.  This test assumes
#       that no other user has been granted permission and therefore
#       will return no rows.

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
  
  def test_023_ColumnPrivileges(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_023)

  def run_test_023(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    if (conn != 0):
      if (server.DBMS_NAME[0:3] == 'IDS'):
        stmt = ibm_db.column_privileges(conn, None, config.user, 'animals')
      else:
        stmt = ibm_db.column_privileges(conn, None, None, 'ANIMALS')
      row = ibm_db.fetch_tuple(stmt)
      if row:
        print row[0]
        print row[1]
        print row[2]
        print row[3]
        print row[4]
        print row[5]
        print row[6]
        print row[7]
      ibm_db.close(conn)
    else:
      print ibm_db.conn_errormsg()
      print "Connection failed\n\n"

#__END__
#__LUW_EXPECTED__
#%s
#%s
#ANIMALS
#BREED
#SYSIBM
#%s
#%s
#YES
#__ZOS_EXPECTED__
#%s
#%s
#ANIMALS
#BREED
#%s
#%s
#%s
#YES
#__SYSTEMI_EXPECTED__
#%s
#%s
#ANIMALS
#BREED
#None
#%s
#%s
#YES
#__IDS_EXPECTED__



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_111_FieldNumAddCol(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_111)

  def run_test_111(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    if conn:
      ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

      insert = "INSERT INTO animals values (7, 'cat', 'Benji', 5.1)"
      ibm_db.exec_immediate(conn, insert)
      
      stmt = ibm_db.exec_immediate(conn, "SELECT breed, COUNT(breed) AS number FROM animals GROUP BY breed ORDER BY breed")
    
      if (server.DBMS_NAME[0:3] == 'IDS'):
        num1 = ibm_db.field_num(stmt, "id")
        num2 = ibm_db.field_num(stmt, "breed")
        num3 = ibm_db.field_num(stmt, "number")
        num4 = ibm_db.field_num(stmt, "NUMBER")
        num5 = ibm_db.field_num(stmt, "bREED")
        num6 = ibm_db.field_num(stmt, 8)
        num7 = ibm_db.field_num(stmt, 1)
        num8 = ibm_db.field_num(stmt, "WEIGHT")
      else:
        num1 = ibm_db.field_num(stmt, "ID")
        num2 = ibm_db.field_num(stmt, "BREED")
        num3 = ibm_db.field_num(stmt, "NUMBER")
        num4 = ibm_db.field_num(stmt, "number")
        num5 = ibm_db.field_num(stmt, "Breed")
        num6 = ibm_db.field_num(stmt, 8)
        num7 = ibm_db.field_num(stmt, 1)
        num8 = ibm_db.field_num(stmt, "weight")
  
      print "%s" % num1
      print "int(%d)" % num2
      print "int(%d)" % num3
      print "%s" % num4
      
      print "%s" % num5
      print "%s" % num6
      print "int(%d)" % num7
      print "%s" % num8

      ibm_db.rollback(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#False
#int(0)
#int(1)
#False
#False
#False
#int(1)
#False
#__ZOS_EXPECTED__
#False
#int(0)
#int(1)
#False
#False
#False
#int(1)
#False
#__SYSTEMI_EXPECTED__
#False
#int(0)
#int(1)
#False
#False
#False
#int(1)
#False
#__IDS_EXPECTED__
#False
#int(0)
#int(1)
#False
#False
#False
#int(1)
#False



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_115_NumericTest_02(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_115)

  def run_test_115(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    server = ibm_db.server_info( conn )
    if (server.DBMS_NAME[0:3] == 'IDS'):
      op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
      ibm_db.set_option(conn, op, 0)
    
    if conn:
      drop = "drop table numericliteral"
      try:
        ibm_db.exec_immediate( conn, drop )
      except:
        pass

      create = "create table numericliteral ( id INTEGER, data VARCHAR(50) )"
      ibm_db.exec_immediate(conn, create)

      insert = "INSERT INTO numericliteral (id, data) values (12, 'NUMERIC LITERAL TEST')"
      ibm_db.exec_immediate(conn, insert)

      stmt = ibm_db.prepare(conn, "SELECT data FROM numericliteral")
      ibm_db.execute(stmt)
      
#      NOTE: This is a workaround
#      function fetch_object() to be implemented...
#      row = ibm_db.fetch_object(stmt, 0)
      
      class Row:
          pass
      
      row = Row()
      ibm_db.fetch_row(stmt, 0)
      if (server.DBMS_NAME[0:3] != 'IDS'):
        row.DATA = ibm_db.result(stmt, 'DATA')
      else:
        row.DATA = ibm_db.result(stmt, 'data')
      print row.DATA

      insert = "UPDATE numericliteral SET data = '@@@@@@@@@@' WHERE id = '12'"
      ibm_db.exec_immediate(conn, insert)

      stmt = ibm_db.prepare(conn, "SELECT data FROM numericliteral")
      ibm_db.execute(stmt)
      
#      row = ibm_db.fetch_object(stmt, 0)
      ibm_db.fetch_row(stmt, 0)
      if (server.DBMS_NAME[0:3] != 'IDS'):
        row.DATA = ibm_db.result(stmt, 'DATA')
      else:
        row.DATA = ibm_db.result(stmt, 'data')
      print row.DATA
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#NUMERIC LITERAL TEST
#@@@@@@@@@@
#__ZOS_EXPECTED__
#NUMERIC LITERAL TEST
#@@@@@@@@@@
#__SYSTEMI_EXPECTED__
#NUMERIC LITERAL TEST
#@@@@@@@@@@
#__IDS_EXPECTED__
#NUMERIC LITERAL TEST
#@@@@@@@@@@



import os
import sys
import struct
import warnings

from setuptools import setup, find_packages
from distutils.core import setup, Extension

PACKAGE = 'ibm_db'
VERSION = '2.0.0'
LICENSE = 'Apache License 2.0'

machine_bits =  8 * struct.calcsize("P")
is64Bit = True
libDir = ''
ibm_db_home = ''
ibm_db_dir = ''
ibm_db_lib = ''

if machine_bits == 64:
    is64Bit = True
    libDir = 'lib64'
    sys.stdout.write("Detected 64-bit Python\n")
else:
    is64Bit = False
    libDir = 'lib32'
    sys.stdout.write("Detected 32-bit Python\m")
    
try:
    ibm_db_home = os.environ['IBM_DB_HOME']
    ibm_db_dir = ibm_db_home
    ibm_db_lib = ibm_db_dir + '/' + libDir
except (KeyError):   
    try:
        ibm_db_dir = os.environ['IBM_DB_DIR']
        ibm_db_lib = ibm_db_dir + '/' + libDir
    except (KeyError):
        sys.stdout.write("Environment variable IBM_DB_HOME is not set. Set it to your DB2/IBM_Data_Server_Driver installation directory and retry ibm_db module install.\n")
        sys.exit()

if not os.path.isdir(ibm_db_lib):
    ibm_db_lib = ibm_db_dir + '/lib'
    if not os.path.isdir(ibm_db_lib):
        sys.stdout.write("Cannot find %s directory. Check if you have set the IBM_DB_HOME environment variable's value correctly\n " %(ibm_db_lib))
        sys.exit()
    notifyString  = "Detected usage of IBM Data Server Driver package. Ensure you have downloaded "
    if is64Bit:
        notifyString = notifyString + "64-bit package "
    else:
        notifyString = notifyString + "32-bit package "
    notifyString = notifyString + "of IBM_Data_Server_Driver and retry the ibm_db module install\n "
    warnings.warn(notifyString)
if not os.path.isdir(ibm_db_dir + '/include'):
    sys.stdout.write(" %s/include folder not found. Check if you have set the IBM_DB_HOME environment variable's value correctly\n " %(ibm_db_dir))
    sys.exit()
    
library = ['db2']
if (sys.platform[0:3] == 'win'):
  library = ['db2cli']

ibm_db = Extension('ibm_db',
                    include_dirs = [ibm_db_dir + '/include'],
                    libraries = library,
                    library_dirs = [ibm_db_lib],
                    sources = ['ibm_db.c'])

modules = ['config', 'ibm_db_dbi', 'testfunctions', 'tests']
extra = {}
if sys.version_info >= (3, ):
    extra['use_2to3'] = True

setup( name    = PACKAGE, 
       version = VERSION,
       license = LICENSE,
       description      = 'Python DBI driver for DB2 (LUW, zOS, i5) and IDS',
       author           = 'IBM Application Development Team',
       author_email     = 'opendev@us.ibm.com',
       url              = 'http://pypi.python.org/pypi/ibm_db/',
       download_url     = 'http://code.google.com/p/ibm-db/downloads/list',
       keywords         = 'database DB-API interface IBM Data Servers DB2 Informix IDS',
       classifiers  = [(sys.version_info >= (3, )) and 'Development Status :: 4 - Beta' or 'Development Status :: 5 - Production/Stable',
                      'Intended Audience :: Developers',
                      'License :: OSI Approved :: Apache Software License',
                      'Operating System :: Microsoft :: Windows :: Windows NT/2000/XP',
                      'Operating System :: Unix',
                      'Topic :: Database :: Front-Ends'],

       long_description = '''
                      This extension is the implementation of Python Database API Specification v2.0
                      The extension supports DB2 (LUW, zOS, i5) and IDS (Informix Dynamic Server)''',
       platforms = 'LinuxIA32, Win32',
       ext_modules  = [ibm_db],
       py_modules   = modules,
       packages     = find_packages(),
       package_data = { 'tests': [ '*.png', '*.jpg']},
       data_files=[ ('', ['./README']),
                    ('', ['./CHANGES']),
                    ('', ['./LICENSE']) ],
       include_package_data = True,
       **extra
     )



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_021_CommitDelete(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_021)

  def run_test_021(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
      
    if conn:
      stmt = ibm_db.exec_immediate(conn, "SELECT count(*) FROM animals")
      res = ibm_db.fetch_tuple(stmt)
      rows = res[0]
      print rows
        
      ibm_db.autocommit(conn, 0)
      ac = ibm_db.autocommit(conn)
      if ac != 0:
        print "Cannot set ibm_db.AUTOCOMMIT_OFF\nCannot run test"
        #continue
        
      ibm_db.exec_immediate(conn, "DELETE FROM animals")
        
      stmt = ibm_db.exec_immediate(conn, "SELECT count(*) FROM animals")
      res = ibm_db.fetch_tuple(stmt)
      rows = res[0]
      print rows
        
      ibm_db.commit(conn)
      
      stmt = ibm_db.exec_immediate(conn, "SELECT count(*) FROM animals")
      res = ibm_db.fetch_tuple(stmt)
      rows = res[0]
      print rows

      # Populate the animal table
      animals = (
        (0, 'cat',        'Pook',         3.2),
        (1, 'dog',        'Peaches',      12.3),
        (2, 'horse',      'Smarty',       350.0),
        (3, 'gold fish',  'Bubbles',      0.1),
        (4, 'budgerigar', 'Gizmo',        0.2),
        (5, 'goat',       'Rickety Ride', 9.7),
        (6, 'llama',      'Sweater',      150)
      )
      insert = 'INSERT INTO animals (id, breed, name, weight) VALUES (?, ?, ?, ?)'
      stmt = ibm_db.prepare(conn, insert)
      if stmt:
        for animal in animals:
          result = ibm_db.execute(stmt, animal)
      ibm_db.commit(conn)
      ibm_db.close(conn)
    else:
      print "Connection failed."
      
#__END__
#__LUW_EXPECTED__
#7
#0
#0
#__ZOS_EXPECTED__
#7
#0
#0
#__SYSTEMI_EXPECTED__
#7
#0
#0
#__IDS_EXPECTED__
#7
#0
#0



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_065_FilterTableName(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_065)

  def run_test_065(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    create = 'CREATE SCHEMA AUTHORIZATION t'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t1( c1 integer, c2 varchar(40))'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t2( c1 integer, c2 varchar(40))'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
      
    create = 'CREATE TABLE t.t3( c1 integer, c2 varchar(40))'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t4( c1 integer, c2 varchar(40))'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
    
    if (server.DBMS_NAME[0:3] == 'IDS'):
      result = ibm_db.tables(conn, None, '%', "t3")
    else:
      result = ibm_db.tables(conn, None, '%', "T3")
    
    columns = ibm_db.num_fields(result)
    
    for i in range(0, columns):
      print "%s, " % ibm_db.field_name(result, i)
    print "\n\n"
   
    row = ibm_db.fetch_tuple(result) 
    while ( row ):
      final = ", " + row[1] + ", " + row[2] + ", " + row[3] + ", , ";
      row = ibm_db.fetch_tuple(result)

    print final
    
    ibm_db.free_result(result)

    ibm_db.exec_immediate(conn, 'DROP TABLE t.t1')
    ibm_db.exec_immediate(conn, 'DROP TABLE t.t2')
    ibm_db.exec_immediate(conn, 'DROP TABLE t.t3')
    ibm_db.exec_immediate(conn, 'DROP TABLE t.t4')

#__END__
#__LUW_EXPECTED__
#TABLE_CAT, TABLE_SCHEM, TABLE_NAME, TABLE_TYPE, REMARKS, 
#
#, T, T3, TABLE, , 
#__ZOS_EXPECTED__
#TABLE_CAT, TABLE_SCHEM, TABLE_NAME, TABLE_TYPE, REMARKS, 
#
#, %sT, T3, TABLE, , 
#__SYSTEMI_EXPECTED__
#TABLE_CAT, TABLE_SCHEM, TABLE_NAME, TABLE_TYPE, REMARKS, 
#
#, T, T3, TABLE, , 
#__IDS_EXPECTED__
#table_cat, table_schem, table_name, table_type, remarks, 
#
#, %sT%s, t3, TABLE%s, ,



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS does not support XML as a native datatype (test is invalid for IDS)

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_195_InsertRetrieveXMLData_01(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_195)

  def run_test_195(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    server = ibm_db.server_info( conn )

    if ((server.DBMS_NAME[0:3] != 'IDS') and (server.DBMS_NAME[0:2] != "AS")):
      drop = 'DROP TABLE test_195'
      try:
        result = ibm_db.exec_immediate(conn, drop)
      except:
        pass
      create = 'CREATE TABLE test_195 (id INTEGER, data XML)'
      result = ibm_db.exec_immediate(conn, create)
    
      insert = "INSERT INTO test_195 values (0, '<TEST><def><xml/></def></TEST>')"
    
      ibm_db.exec_immediate(conn, insert)
    
      sql =  "SELECT data FROM test_195"
      stmt = ibm_db.prepare(conn, sql)
      ibm_db.execute(stmt)
      result = ibm_db.fetch_assoc(stmt)
      while( result ):
        print "Output:", result
        result = ibm_db.fetch_assoc(stmt)
      ibm_db.close(conn)
    else:
      print "Native XML datatype is not supported."

#__END__
#__LUW_EXPECTED__
#Output:%s<TEST><def><xml/></def></TEST>
#__ZOS_EXPECTED__
#Output:%s<TEST><def><xml/></def></TEST>
#__SYSTEMI_EXPECTED__
#Native XML datatype is not supported.
#__IDS_EXPECTED__
#Native XML datatype is not supported.



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_100_SelectDeleteInsertFieldCount(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_100)

  def run_test_100(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    if conn:
      ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

      stmt = ibm_db.exec_immediate(conn, "SELECT * FROM animals ORDER BY breed")
    
      fields1 = ibm_db.num_fields(stmt)
      
      print "int(%d)" % fields1
      
      stmt = ibm_db.exec_immediate(conn, "SELECT name, breed FROM animals ORDER BY breed")
      fields2 = ibm_db.num_fields(stmt)
      
      print "int(%d)" % fields2
      
      stmt = ibm_db.exec_immediate(conn, "DELETE FROM animals")
      fields3 = ibm_db.num_fields(stmt)
      
      print "int(%d)" % fields3
      
      stmt = ibm_db.exec_immediate(conn, "INSERT INTO animals values (0, 'cat', 'Pook', 3.2)")
      fields4 = ibm_db.num_fields(stmt)
        
      print "int(%d)" % fields4
      
      stmt = ibm_db.exec_immediate(conn, "SELECT name, breed, 'TEST' FROM animals")
      fields5 = ibm_db.num_fields(stmt)
        
      print "int(%d)" % fields5

      ibm_db.rollback(conn)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#int(4)
#int(2)
#int(0)
#int(0)
#int(3)
#__ZOS_EXPECTED__
#int(4)
#int(2)
#int(0)
#int(0)
#int(3)
#__SYSTEMI_EXPECTED__
#int(4)
#int(2)
#int(0)
#int(0)
#int(3)
#__IDS_EXPECTED__
#int(4)
#int(2)
#int(0)
#int(0)
#int(3)



test_dir	=	'tests'		# Location of testsuite file (relative to current directory) (Don't change this.)

database	=	'sample'	# Database to connect to. Please use an empty database for best results.
user		=	'db2inst1'	# User ID to connect with
password	=	'password'	# Password for given User ID
hostname	=	'localhost'	# Hostname
port		=	60000		# Port Number

auth_user	=	'auth_user'	# Authentic user of Database
auth_pass	=	'auth_pass'	# Password for Authentic user
tc_user		=	'tc_user'	# Trusted user
tc_pass		=	'tc_pass'	# Password to trusted user



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from decimal import Decimal
import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
	def test_decimal(self):
		obj = IbmDbTestFunctions()
		obj.assert_expect(self.run_test_decimal)
	
	def run_test_decimal(self):
		conn = ibm_db.connect(config.database, config.user, config.password)
		
		if conn:
			serverinfo = ibm_db.server_info( conn )
			
			drop = "DROP TABLE STOCKSHARE"
			try:
				result = ibm_db.exec_immediate(conn,drop)
			except:
				pass
			
			# Create the table stockprice
			create = "CREATE TABLE STOCKSHARE (id SMALLINT NOT NULL, company VARCHAR(30), stockshare DECIMAL(7, 2))"
			result = ibm_db.exec_immediate(conn, create)
			
			# Insert Directly
			insert = "INSERT INTO STOCKSHARE (id, company, stockshare) VALUES (10, 'Megadeth', 100.002)"
			result = ibm_db.exec_immediate(conn, insert)
			
			# Prepare and Insert in the stockprice table
			stockprice = (\
					(20, "Zaral", 102.205),\
					(30, "Megabyte", "98.65"),\
					(40, "Visarsoft", Decimal("123.34")),\
					(50, "Mailersoft", Decimal("134.222")),\
					(60, "Kaerci", Decimal("100.976"))\
					)
			insert = 'INSERT INTO STOCKSHARE (id, company, stockshare) VALUES (?,?,?)'
			stmt = ibm_db.prepare(conn,insert)
			if stmt:
				for company in stockprice:
					result = ibm_db.execute(stmt,company)
			
			id = 70
			company = 'Nirvana'
			stockshare = Decimal("100.1234")
			try:
				ibm_db.bind_param(stmt, 1, id)
				ibm_db.bind_param(stmt, 2, company)
				ibm_db.bind_param(stmt, 3, stockshare)
				error = ibm_db.execute(stmt);
			except:
				excp = sys.exc_info()
				# slot 1 contains error message
				print excp[1]
			
			# Select the result from the table and
			query = 'SELECT * FROM STOCKSHARE ORDER BY id'
			if (serverinfo.DBMS_NAME[0:3] != 'IDS'):
				stmt = ibm_db.prepare(conn, query, {ibm_db.SQL_ATTR_CURSOR_TYPE: ibm_db.SQL_CURSOR_KEYSET_DRIVEN})
			else:
				stmt = ibm_db.prepare(conn, query)
			ibm_db.execute(stmt)
			data = ibm_db.fetch_both( stmt )
			while ( data ):
				print "%s : %s : %s\n" % (data[0], data[1], data[2])
				data = ibm_db.fetch_both( stmt )
			try:
				stmt = ibm_db.prepare(conn, query, {ibm_db.SQL_ATTR_CURSOR_TYPE:  ibm_db.SQL_CURSOR_KEYSET_DRIVEN})
				ibm_db.execute(stmt)
				rc = ibm_db.fetch_row(stmt, -1)
				print "Fetch Row -1:%s " %str(rc)
			except:
				print "Requested row number must be a positive value"
			ibm_db.close(conn)
		else:
			print "Connection failed."

#__END__
#__LUW_EXPECTED__
#10 : Megadeth : 100.00
#20 : Zaral : 102.20
#30 : Megabyte : 98.65
#40 : Visarsoft : 123.34
#50 : Mailersoft : 134.22
#60 : Kaerci : 100.97
#70 : Nirvana : 100.12
#Requested row number must be a positive value
#__ZOS_EXPECTED__
#10 : Megadeth : 100.00
#20 : Zaral : 102.20
#30 : Megabyte : 98.65
#40 : Visarsoft : 123.34
#50 : Mailersoft : 134.22
#60 : Kaerci : 100.97
#70 : Nirvana : 100.12
#Requested row number must be a positive value




# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_060_Tables_01(self):
    obj = IbmDbTestFunctions()
    obj.assert_expectf(self.run_test_060)

  def run_test_060(self):
    conn = ibm_db.connect(config.database, config.user, config.password)

    create = 'CREATE SCHEMA AUTHORIZATION t'
    try:
      result = ibm_db.exec_immediate(conn, create)
    except:
      pass
    
    create = 'CREATE TABLE t.t1( c1 INTEGER, c2 VARCHAR(40))'
    try:
      result = ibm_db.exec_immediate(conn, create)
    except:
      pass
    
    create = 'CREATE TABLE t.t2( c1 INTEGER, c2 VARCHAR(40))'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t3( c1 INTEGER, c2 VARCHAR(40))'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
    
    create = 'CREATE TABLE t.t4( c1 INTEGER, c2 VARCHAR(40))'
    try:
      result = ibm_db.exec_immediate(conn, create) 
    except:
      pass
    
    if conn:
      result = ibm_db.tables(conn, None, 'T')
      i = 0
      row = ibm_db.fetch_both(result)
      while ( row ):
        if (i < 4):
          print "/%s/%s" % (row[1], row[2])
        i = i + 1
        row = ibm_db.fetch_both(result)

      ibm_db.exec_immediate(conn, 'DROP TABLE t.t1')
      ibm_db.exec_immediate(conn, 'DROP TABLE t.t2')
      ibm_db.exec_immediate(conn, 'DROP TABLE t.t3')
      ibm_db.exec_immediate(conn, 'DROP TABLE t.t4')

      print "done!"
    else:
      print "no connection: #{ibm_db.conn_errormsg}";    

#__END__
#__LUW_EXPECTED__
#/T/T1
#/T/T2
#/T/T3
#/T/T4
#done!
#__ZOS_EXPECTED__
#/T/T1
#/T/T2
#/T/T3
#/T/T4
#done!
#__SYSTEMI_EXPECTED__
#/T/T1
#/T/T2
#/T/T3
#/T/T4
#done!
#__IDS_EXPECTED__
#/T%s/t1
#/T%s/t2
#/T%s/t3
#/T%s/t4
#done!



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_015_InsertDeleteRowCount_01(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_015)

  def run_test_015(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    if conn:
      result = ibm_db.exec_immediate(conn,"insert into t_string values(123,1.222333,'one to one')")
      if result:
        cols = ibm_db.num_fields(result)
        # NOTE: Removed '\n' from the following and a few more prints here (refer to ruby test_015.rb)
        print "col:", cols
        rows = ibm_db.num_rows(result)
        print "affected row:", rows
      else:
        print ibm_db.stmt_errormsg()
      result = ibm_db.exec_immediate(conn,"delete from t_string where a=123")
      if result:
        cols = ibm_db.num_fields(result)
        print "col:", cols
        rows = ibm_db.num_rows(result)
        print "affected row:", rows
      else:
        print ibm_db.stmt_errormsg()
      ibm_db.close(conn)
    else:
      print "no connection:", ibm_db.conn_errormsg()

#__END__
#__LUW_EXPECTED__
#col: 0
#affected row: 1
#col: 0
#affected row: 1
#__ZOS_EXPECTED__
#col: 0
#affected row: 1
#col: 0
#affected row: 1
#__SYSTEMI_EXPECTED__
#col: 0
#affected row: 1
#col: 0
#affected row: 1
#__IDS_EXPECTED__
#col: 0
#affected row: 1
#col: 0
#affected row: 1



import os
import sys
import unittest
import StringIO
import re
import glob
import inspect

import ibm_db
import config

class IbmDbTestFunctions(unittest.TestCase):
  
  # See the tests.py comments for this function.
  def setUp(self):
    pass
 
  # This function captures the output of the current test file.
  def capture(self, func):
    buffer = StringIO.StringIO()
    sys.stdout = buffer
    func()
    sys.stdout = sys.__stdout__
    var = buffer.getvalue()
    var = var.replace('\n', '').replace('\r', '')
    return var
  
  # This function grabs the expected output of the current test function for LUW,
  #   located at the bottom of the current test file.
  def expected_LUW(self, fileName):
    fileHandle = open(fileName, 'r')
    fileInput = fileHandle.read().split('#__LUW_EXPECTED__')[-1].split('#__ZOS_EXPECTED__')[0].replace('\n', '').replace('#', '')
    fileHandle.close()
    return fileInput

  # This function grabs the expected output of the current test function for IDS,
  #   located at the bottom of the current test file.
  def expected_IDS(self, fileName):
    fileHandle = open(fileName, 'r')
    fileInput = fileHandle.read().split('#__IDS_EXPECTED__')[-1].replace('\n', '').replace('#', '')
    fileHandle.close()
    return fileInput

  # This function grabs the expected output of the current test function for zOS,
  #   located at the bottom of the current test file.
  def expected_ZOS(self, fileName):
    fileHandle = open(fileName, 'r')
    fileInput = fileHandle.read().split('#__ZOS_EXPECTED__')[-1].split('#__SYSTEMI_EXPECTED__')[0].replace('\n', '').replace('#', '')
    fileHandle.close()
    return fileInput

  # This function grabs the expected output of the current test function for zOS,
  #   located at the bottom of the current test file.
  def expected_AS(self, fileName):
    fileHandle = open(fileName, 'r')
    fileInput = fileHandle.read().split('#__SYSTEMI_EXPECTED__')[-1].split('#__IDS_EXPECTED__')[0].replace('\n', '').replace('#', '')
    fileHandle.close()
    return fileInput
    
  # This function compares the captured outout with the expected out of
  #   the current test file.
  def assert_expect(self, testFuncName):
    callstack = inspect.stack(0)
    try:
      prepconn = ibm_db.connect(config.database, config.user, config.password)
      server = ibm_db.server_info(prepconn)
      ibm_db.close(prepconn)
      if (server.DBMS_NAME[0:2] == "AS"):
          self.assertEqual(self.capture(testFuncName), self.expected_AS(callstack[1][1]))
      elif (server.DBMS_NAME == "DB2"):
          self.assertEqual(self.capture(testFuncName), self.expected_ZOS(callstack[1][1]))
      elif (server.DBMS_NAME[0:3] == "IDS"):
          self.assertEqual(self.capture(testFuncName), self.expected_IDS(callstack[1][1]))
      else:
          self.assertEqual(self.capture(testFuncName), self.expected_LUW(callstack[1][1]))
      
    finally:
      del callstack

  # This function will compare using Regular Expressions
  # based on the servre
  def assert_expectf(self, testFuncName):
    callstack = inspect.stack(0)
    try:
      prepconn = ibm_db.connect(config.database, config.user, config.password)
      server = ibm_db.server_info(prepconn)
      ibm_db.close(prepconn)
      if (server.DBMS_NAME[0:2] == "AS"):
          pattern = self.expected_AS(callstack[1][1])
      elif (server.DBMS_NAME == "DB2"):
          pattern = self.expected_ZOS(callstack[1][1])
      elif (server.DBMS_NAME[0:3] == "IDS"):
          pattern = self.expected_IDS(callstack[1][1])
      else:
          pattern = self.expected_LUW(callstack[1][1])
      
      sym = ['\[','\]','\(','\)']
      for chr in sym:
          pattern = re.sub(chr, '\\' + chr, pattern)

      pattern = re.sub('%s', '.*?', pattern)
      pattern = re.sub('%d', '\\d+', pattern)

      result = re.match(pattern, self.capture(testFuncName))
      self.assertNotEqual(result, None)
    finally:
      del callstack
      
  #def assert_throw_blocks(self, testFuncName):
  #  callstack = inspect.stack(0)
  #  try:

  # This function needs to be declared here, regardless of if there 
  #   is any body to this function
  def runTest(self):
    pass



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_140_BindParamSelectStmt(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_140)

  def run_test_140(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    if conn:
      stmt = ibm_db.prepare(conn, "SELECT id, breed, name, weight FROM animals WHERE id = ?")
    
      animal = 0
      ibm_db.bind_param(stmt, 1, animal)
    
      if ibm_db.execute(stmt):
        row = ibm_db.fetch_tuple(stmt)
        while ( row ): 
          #roiw.each { |child| puts child }
          for i in row:
            print i
          row = ibm_db.fetch_tuple(stmt)
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#0
#cat
#Pook            
#3.20
#__ZOS_EXPECTED__
#0
#cat
#Pook            
#3.20
#__SYSTEMI_EXPECTED__
#0
#cat
#Pook            
#3.20
#__IDS_EXPECTED__
#0
#cat
#Pook            
#3.20



# 
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

import unittest, sys
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

  def test_147_PrepareWithWrongType(self):
    obj = IbmDbTestFunctions()
    obj.assert_expect(self.run_test_147)

  def run_test_147(self):
    conn = ibm_db.connect(config.database, config.user, config.password)
    
    if conn:
      ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

      stmt = ibm_db.prepare(conn, "INSERT INTO animals (id, breed, name) VALUES (?, ?, ?)")
    
      id = "\"999\""
      breed = None
      name = 'PythonDS'
      try:
          ibm_db.bind_param(stmt, 1, id)
          ibm_db.bind_param(stmt, 2, breed)
          ibm_db.bind_param(stmt, 3, name)
       
          error = ibm_db.execute(stmt)
          print "Should not make it this far"
      except:
          excp = sys.exc_info()
          # slot 1 contains error message
          print excp[1]
    else:
      print "Connection failed."

#__END__
#__LUW_EXPECTED__
#Statement Execute Failed: [IBM][CLI Driver] CLI0112E  Error in assignment. SQLSTATE=22005 SQLCODE=-99999
#__ZOS_EXPECTED__
#Statement Execute Failed: [IBM][CLI Driver] CLI0112E  Error in assignment. SQLSTATE=22005 SQLCODE=-99999
#__SYSTEMI_EXPECTED__
#Statement Execute Failed: [IBM][CLI Driver] CLI0112E  Error in assignment. SQLSTATE=22005 SQLCODE=-99999
#__IDS_EXPECTED__
#Statement Execute Failed: [IBM][CLI Driver] CLI0112E  Error in assignment. SQLSTATE=22005 SQLCODE=-99999
